# -*- encoding=utf-8 -*-
import os
import time
import wadeTools_ErZhiHua
import wadeTools_DuiBiJPG
import cv2
import wadeTools_ScreenShot
'''
by：shenhuawade
qq: 317909531
功能：负责比对两幅图的相似度，越接近0越相似，越接近1，越差异

find_picture()
------------------------------------------
输入参数target: 待搜素的大图
输入参数template: 搜素的小图，尺寸必须小于target
-------------------------------------------
输出参数min_val: 越接近0越相似，越接近1越偏离，0.005以下基本可以认为是准确的
输出参数x: 匹配左上角的位置，用于定位
输出参数y: 匹配左上角的位置，用于定位
------------------------------------------
code/time:2019.12.29
'''

"""
matchTemplate():
参数image:待搜索的图像(大图)
参数temple:搜索模板,需要和原图一样的数据类型且尺寸不能大于源图像
参数result:比较结果的映射图像,其必须为单通道,32位浮点型图像,如果原图(待搜索图像)尺寸为W*H,而temple尺寸为w*h,则result尺寸一定是
    (W-w+1)*(H-h+1)
参数method:指定匹配方法,有如下几种:
    CV_TM_SQDIFF:平方差匹配法
    CV_TM_SQDIFF_NORMED:归一化平方差匹配法
    CV_TM_CCORR:相关匹配法
    CV_TM_CCORR_NORMED:归一化相关匹配法
    CV_TM_CCOEFF:系数匹配法
    CV_TM_CCOEFF_NORMED:化相关系数匹配法
"""
"""
minMaxLoc()函数
作用:一维数组当作向量,寻找矩阵中最小值和最大值位置
"""

def find_picture(target,template):
    # #二值化处理
    target= wadeTools_ErZhiHua.custom_threshold(target)
    template= wadeTools_ErZhiHua.custom_threshold(template)

    #获得模板图片的高宽尺寸
    theight, twidth = template.shape[:2]

    '''相似度对比'''
    #执行模板匹配，采用的匹配方式cv2.TM_SQDIFF_NORMED
    result1 = cv2.matchTemplate(target,template,cv2.TM_SQDIFF_NORMED)    #趋近于0
    min_val1, max_val1, min_loc1, max_loc1 = cv2.minMaxLoc(result1)
    # cv2.normalize(result1, result1, 0, 1, cv2.NORM_MINMAX, -1)
    '''汉明距离对比'''
    cropped = target[min_loc1[1]:min_loc1[1] + theight, min_loc1[0]:min_loc1[0] + twidth]  # 裁剪坐标为[y0:y1, x0:x1]
    cv2.imencode('.png', cropped)[1].tofile(os.path.join('shotImgLOG', f"{int(round(time.time() * 1000))}找到的图.png"))
    cv2.imencode('.png', template)[1].tofile(os.path.join('shotImgLOG', f"{int(round(time.time() * 1000))}myimage模版图.png"))
    # cv2.imwrite(os.path.join('shotImgLOG', f"{int(round(time.time() * 1000))}__zhao.png"), cropped)
    # cv2.imwrite(os.path.join('shotImgLOG', f"{int(round(time.time() * 1000))}__myimage模版图.png"), template)
    # 利用pil 的格式进行汉明距离测试
    # 先把template的numpy格式转为pil的img
    from PIL import Image
    # similary 越接近1说明两张图相符
    similary = wadeTools_DuiBiJPG.phash_img_similarity(Image.fromarray(template), Image.fromarray(cropped))


        # 真正的找到了
    targetCopy = target  #在副本上画线框，不污染原图，后边还需要在原图上截取图片做汉明距离比对，所以不能污染原图
    cv2.rectangle(targetCopy, min_loc1, (min_loc1[0] + twidth, min_loc1[1] + theight), (0, 0, 225), 2)
    # cv2.namedWindow("RGBimg--ShowasGBRimg", cv2.WINDOW_NORMAL)
    # cv2.imshow(f"RGBimg--ShowasGBRimg", target)
    imgname = f"{int(round(time.time() * 1000))}自定义找图范围.png"
    # cv2.imwrite(os.path.join('shotImgLOG',imgname),targetCopy)
    cv2.imencode('.png', targetCopy)[1].tofile(os.path.join('shotImgLOG',imgname))


    # cv2.namedWindow("RGBimg--ShowasGBRimg2", cv2.WINDOW_NORMAL)
    # cv2.imshow(f"RGBimg--ShowasGBRimg2", targetCopy)
    # cv2.waitKey(0)
    # cv2.destroyAllWindows()

    #拿到了最佳点之后，通过xy就可以截取到这个屏幕图片的局部
    #对大图片裁切，对比他们的特征码，如果明汉距离通过，说明是真的对比成功



    x = min_loc1[0]
    y = min_loc1[1]
    # 矩形框的长和宽
    return min_val1, x, y, similary, twidth, theight



if __name__ == '__main__':
    # wadeTools_ScreenShot.screenShot()
    # target = cv2.imread('c.png')[:, :, ::-1]   #因为cv2.imread读取的是gbr通道，需要反转成rgb格式
    # template = cv2.imread('t.png')[:, :, ::-1]
    # print(type(target))
    # # 通道反转img[:, :, ::-1]
    #
    # #不做灰度对比效果
    # min_val1, x, y, similary, twidth, theight = find_picture(target,template)
    # print(min_val1,similary)


    # 做灰度对比效果
    target = cv2.imread('8.png')[:, :, ::-1]  # 因为cv2.imread读取的是gbr通道，需要反转成rgb格式
    template = cv2.imread('8.png')[:, :, ::-1]
    # cv2.namedWindow('input_image')  # 设置为WINDOW_NORMAL可以任意缩放
    # cv2.imshow('input_image', target)
    target_ErZhi_numpy = wadeTools_ErZhiHua.custom_threshold(target)  # 获取目标图片的灰度二值化图片
    cv2.namedWindow("target_ErZhi_numpy", cv2.WINDOW_NORMAL)
    cv2.imshow("target_ErZhi_numpy", target_ErZhi_numpy)
    # wadeTools_ErZhiHua.local_threshold(target)
    # wadeTools_ErZhiHua.custom_threshold(target)
    template_ErZhi_numpy = wadeTools_ErZhiHua.custom_threshold(template)  # 获取模板中图片的灰度二值化图片
    cv2.namedWindow("template_ErZhi_numpy", cv2.WINDOW_NORMAL)
    cv2.imshow("template_ErZhi_numpy", template_ErZhi_numpy)

    cv2.waitKey(0)
    cv2.destroyAllWindows()
    print(type(target))
    # 通道反转img[:, :, ::-1]

    # # 不做灰度对比效果
    # min_val1, x, y, similary, twidth, theight = find_picture(target_ErZhi_numpy, template_ErZhi_numpy)
    # print(min_val1)
    # print(similary)




    '''AttributeError: 'NoneType' object has no attribute 'shape
        报错是因为图片路径问题
    '''


# coding:utf-8
# 单例模式
"""可以解决全局变量的难题，保证在线程之间的通信，实现信息表的统一管理"""

import threading
import time
# from wadeTools import wadeTools_log

class Singletion(object):

    '''外部存储的是类成员变量，实例化中__dict__不会保存这类内容
    用它来持久化：pickle不能序列化的变量
    '''
    instance  = None
    __init__flag = False
    lock = threading.RLock()
    windows={}
    # my_logger = wadeTools_log.MyLogger.create_logger()
    def __init__(self):
        if not Singletion.__init__flag:
            # print('init执行了')
            self.name = '全局变量'
            self._global_dict = {}  # 保存全局变量,不要直接赋值获取，用set get来获取不会报错
            self._gol_ui_dict = {}  # 保存全局UI变量,不要直接赋值获取，用set get来获取不会报错
            Singletion.__init__flag = True

    def __new__(cls, *args, **kwargs):
        # 返回空对象，init中的跨文件不能用
        # 返回空对象
        with cls.lock:
            if cls.instance is None:
                cls.instance = super().__new__(cls)
            return cls.instance


    def gol_save_value(self, key, value):
        self._global_dict[key] = value  # 定义一个全局变量

    def gol_get_value(self, key):
        try:
            return self._global_dict[key]  # 获得一个全局变量，不存在则提示读取对应变量失败
        except:
            print('全局字典中没有：' + key + '键值\r\n')

    def gol_print_value(self):
        print(self._global_dict)

    def gol_clear_value(self):
        self._global_dict = {}

    def ui_save_Value(self, key, value):  # 保存UI中变量的方法
        self._gol_ui_dict[key] = value

    def ui_get_Value(self, key):  # 获得一个全局变量，不存在则提示读取对应变量失败
        try:
            return self._gol_ui_dict[key]
        except:
            print('全局UI字典中没有：' + key + '键值\r\n')

    def ui_print_value(self):
        print(self._gol_ui_dict)

    def ui_clear_value(self):
        self._global_dict = {}


if __name__ == '__main__':

    gol = Singletion


    # gol.printgol()

    def work1():
        from wadeTools import acd
        #
        acd.works()
        # works()
        # print(gol)
        # num = 1
        # while True:
        #     num = num + 1
        #     gol.gol_save_value('aaa', num)
        #     time.sleep(3)
        #     print(333)
        #     print(gol.__dict__)
    def work2():
        gol = Singletion()
        print(gol)



    s1 = threading.Thread(target=work1)
    s2 = threading.Thread(target=work2)
    # s1.setDaemon(True)
    # s2.setDaemon(True)
    s1.start()
    s2.start()

    # gol.printgol()

    print(gol)
    time.sleep(2)




#!/usr/bin/env python
# coding=utf-8
# 最右 加词api
import time

import requests
import json

from wadeTools.wadeTools_Print import wadePrint



def easy回填(project_id):
    # 一次性回填，只需要填写工程名就行
    import requests
    import json

    url = "https://newapi.thed1g.com/v2api/keyword/myKeywordList"

    payload = json.dumps({
        "project_id": f"{project_id}",
        "type": 0,
        "status": -1,
        "page": 1,
        "list_rows": 500,
        "keyword": ""
    })
    headers = {
        'Host': 'newapi.thed1g.com',
        'content-type': 'application/json',
        'xweb_xhr': '1',
        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36 MicroMessenger/7.0.20.1781(0x6700143B) NetType/WIFI MiniProgramEnv/Windows WindowsWechat/WMPF WindowsWechat(0x6309080f)XWEB/8461',
        'token': '6b62389f691d4d8b1b9d0279b2f47135',
        'schoolo': 'd01cdb015332f142e0e6e510e8855f89',
        'accept': '*/*',
        'sec-fetch-site': 'cross-site',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://servicewechat.com/wxbe60c88472c90f82/123/page-frame.html',
        'accept-language': 'zh-CN,zh;q=0.9'
    }

    response = requests.request("POST", url, headers=headers, data=payload)

    # print(response.text)
    print(json.loads(response.text)['data']['data'])
    dataList = json.loads(response.text)['data']['data']
    for item in dataList:
        if item['status_text']=='待发布': # 审核通过的词
            # 提交回填
            item_id = item['id']
            project_id = item['project_id']
            title = item['keyword']
            create_time = item['create_time']
            article_url = item['create_time']
            回填(project_id=project_id,title=title,create_time=create_time,item_id=item_id)
            time.sleep(4)
        else:
            print(f"{item['keyword']}   ，{item['status_text']}")

def 回填(project_id,title,create_time,item_id):
    import requests
    import json
    from datetime import datetime

    # 获取当前日期和时间
    now = datetime.now()

    # 格式化日期为 "YYYY-MM-DD"
    formatted_date = now.strftime("%Y-%m-%d")

    # print(formatted_date)
    url = "https://newapi.thed1g.com/api/keyword/publish"

    payload = json.dumps({
        "keywordInfo": {
            "title": title,
            "create_time": create_time,
            "id": item_id,
            "project_id": project_id
        },
        "is_add": 0,
        "formData": [
            {
                "video_url": "https://v.douyin.com/iR7toCUa/",
                "play_num": "",
                "like_num": "",
                "publish_platform": "抖音KOC",
                "account_name": "张博绝绝子",
                "account_id": 510957,
                "publish_time": f"{formatted_date}"
            }
        ]
    })
    headers = {
        'Host': 'newapi.thed1g.com',
        'content-type': 'application/json',
        'xweb_xhr': '1',
        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36 MicroMessenger/7.0.20.1781(0x6700143B) NetType/WIFI MiniProgramEnv/Windows WindowsWechat/WMPF WindowsWechat(0x6309080f)XWEB/8461',
        'token': '6b62389f691d4d8b1b9d0279b2f47135',
        'schoolo': 'd01cdb015332f142e0e6e510e8855f89',
        'accept': '*/*',
        'sec-fetch-site': 'cross-site',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://servicewechat.com/wxbe60c88472c90f82/123/page-frame.html',
        'accept-language': 'zh-CN,zh;q=0.9'
    }

    response = requests.request("POST", url, headers=headers, data=payload)

    wadePrint(response.text)


def addMyWord_ZUIYOU(addword,wenzhangurl,project_id):
    print(addword,wenzhangurl,project_id)

    import requests
    import json

    url = "https://newapi.thed1g.com/v2api/KeywordV5/add"

    payload = json.dumps({
        "formData": [
            [
                {
                    "front_msg": "5-20个汉字",
                    "max_len": 20,
                    "min_len": 5,
                    "name": f"addword",
                    "field": "keyword",
                    "var_type": 2,
                    "is_empty": 1,
                    "is_copy": 1,
                    "type": 0,
                    "value":addword,
                    "typeList": [
                        ""
                    ]
                },
                {
                    "front_msg": "",
                    "max_len": 0,
                    "min_len": 0,
                    "name": "文章链接",
                    "field": "article_url",
                    "var_type": 1,
                    "is_empty": 1,
                    "is_copy": 1,
                    "type": 0,
                    "value": f"{wenzhangurl}",
                    "typeList": [
                        ""
                    ]
                }
            ]
        ],
        "project_id": f"{project_id}"
    })
    headers = {
        'Host': 'newapi.thed1g.com',
        'content-type': 'application/json',
        'xweb_xhr': '1',
        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36 MicroMessenger/7.0.20.1781(0x6700143B) NetType/WIFI MiniProgramEnv/Windows WindowsWechat/WMPF WindowsWechat(0x6309001c)XWEB/8461',
        'token': '6b62389f691d4d8b1b9d0279b2f47135',
        'schoolo': 'd01cdb015332f142e0e6e510e8855f89',
        'accept': '*/*',
        'sec-fetch-site': 'cross-site',
        'sec-fetch-mode': 'cors',
        'sec-fetch-dest': 'empty',
        'referer': 'https://servicewechat.com/wxbe60c88472c90f82/119/page-frame.html',
        'accept-language': 'zh-CN,zh;q=0.9'
    }

    response = requests.request("POST", url, headers=headers, data=payload)

    print(response.text)


if __name__ == '__main__':




    # addword = '女指导员的哀嚎'
    # wenzhangurl = 'http://dy.163.com/v2/article/detail/II9TMH1A052188CT.html'
    # addMyWord_ZUIYOU(addword,wenzhangurl,52)
    easy回填(project_id=52)
    # 回填(project_id=52, title="晴晴资金录", create_time="2023-11-30 16:36:39", item_id=5159)



"""
使用方法：
send_feishu_message()  可以独立调用
👇是调用方法


send_feishu_message(message_content="你好，我是旺财")

"""

from openpyxl import Workbook
from openpyxl.reader.excel import load_workbook
from openpyxl.styles import Alignment, NamedStyle, Border, Side
from openpyxl.utils import get_column_letter
import pandas as pd
# 导入外部工具类（保持原引用）
from wadeTools.wadeTools_Print import wadePrint, wadeRedPrint
from wadeTools import (
    wadeTools_lock, wadeTools_getSystemInfo,
)
from wadeTools.wadeTools_Print import wadePrint
import os
import time
import asyncio
import importlib.util

import lark_oapi as lark

from lark_oapi.api.im.v1 import P2ImMessageReceiveV1, CreateMessageRequest, CreateMessageRequestBody, CreateMessageResponse
from datetime import datetime, timedelta
import json
import requests

# --------------------------
# 配置应用凭证（替换为你的实际信息）
# --------------------------
APP_ID = "cli_a8104951b66b900c"  # 从开发者后台获取
APP_SECRET = "0AwayvK6wJMxjuwcDl8B2c1r5qPybEaw"  # 从开发者后台获取

# 全局变量存储访问令牌及过期时间
access_token = None
token_expire_time = None


class AutoTaskRunner:
    """自动发现并运行任务的本地库组件"""

    # def __init__(self, tasks_dir=r"F:\code\wadeTools\wadeTools\RobotTasks"):
    def __init__(self, tasks_dir="RobotTasks"):
        # 这表示tasks_dir是当前工作目录下的RobotTasks文件夹
        self.tasks_dir = tasks_dir
        self._load_tasks()  # 初始化时自动扫描任务

    def _load_tasks(self):
        """扫描 tasks/ 目录下所有任务文件并加载"""
        self.tasks = []
        if not os.path.exists(self.tasks_dir):
            os.makedirs(self.tasks_dir)
            return

        # 遍历目录下所有 .py 文件
        for filename in os.listdir(self.tasks_dir):
            if filename.endswith(".py") and not filename.startswith("__"):
                self._load_task_module(filename)

    def _load_task_module(self, filename):
        """加载单个任务模块"""
        module_name = filename[:-3]
        file_path = os.path.join(self.tasks_dir, filename)

        # 动态导入模块
        spec = importlib.util.spec_from_file_location(module_name, file_path)
        module = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(module)

        # 检查模块是否包含 async run 函数（约定接口）
        if hasattr(module, "run") and asyncio.iscoroutinefunction(module.run):
            self.tasks.append(module.run)
            print(f"[自动发现任务] {filename}")

    async def run_all_tasks(self, message_data):
        """执行所有发现的任务"""
        if not self.tasks:
            return
        await asyncio.gather(*[task(message_data) for task in self.tasks])
# --------------------------
# 本地库的事件处理逻辑（永不修改）
# --------------------------
task_runner = AutoTaskRunner()  # 初始化自动任务运行器
# --------------------------
# 获取访问令牌
# --------------------------
def get_access_token():
    global access_token, token_expire_time

    # 检查令牌是否有效（提前30秒过期，避免网络延迟问题）
    if access_token and token_expire_time and datetime.now() < token_expire_time - timedelta(seconds=30):
        return access_token

    # 调用获取令牌接口
    url = "https://open.feishu.cn/open-apis/auth/v3/tenant_access_token/internal"
    headers = {"Content-Type": "application/json"}
    payload = json.dumps({"app_id": APP_ID, "app_secret": APP_SECRET})

    response = requests.post(url, headers=headers, data=payload)
    result = response.json()

    if "tenant_access_token" in result:
        access_token = result["tenant_access_token"]
        # 设置过期时间
        token_expire_time = datetime.now() + timedelta(seconds=result["expire"])
        print("获取访问令牌成功")
        return access_token
    else:
        print(f"获取访问令牌失败: {result}")
        return None


# --------------------------
# 发送消息函数（使用requests实现）
# --------------------------
def send_message(chat_id: str, content: str, chat_type: str = "p2p"):
    """
    发送消息到飞书
    :param chat_id: 会话ID
    :param content: 消息内容（文本）
    :param chat_type: 会话类型，"p2p"表示单聊，"group"表示群聊
    """
    # 获取访问令牌
    token = get_access_token()
    if not token:
        print("无法获取访问令牌，发送消息失败")
        return

    # 构建请求参数
    url = "https://open.feishu.cn/open-apis/im/v1/messages"
    params = {"receive_id_type": "chat_id"}
    msg_content = {
        "text": content
    }
    req = {
        "receive_id": chat_id,
        "msg_type": "text",
        "content": json.dumps(msg_content)
    }
    print(req)
    payload = json.dumps(req)
    headers = {
        'Authorization': f'Bearer {token}',
        'Content-Type': 'application/json'
    }

    # 发送请求
    response = requests.post(url, params=params, headers=headers, data=payload)

    # 处理响应
    print(f"消息发送响应日志ID: {response.headers.get('X-Tt-Logid')}")
    if response.status_code == 200:
        result = response.json()
        if result.get("code") == 0:
            print(f"消息发送成功，消息ID: {result.get('data', {}).get('message_id')}")
        else:
            print(f"发送消息失败: {result}")
    else:
        print(f"发送请求失败，状态码: {response.status_code}，响应内容: {response.text}")


# --------------------------
# 消息事件处理函数（接收用户消息并回复）
# --------------------------
def handle_message(data: P2ImMessageReceiveV1) -> None:
    try:
        # 提取消息基本信息
        event = data.event
        chat_id = event.message.chat_id
        chat_type = event.message.chat_type  # "p2p"表示单聊，"group"表示群聊
        message_type = event.message.message_type
        message_id = event.message.message_id
        sender_id = event.sender.sender_id.user_id

        # 解析文本消息内容
        if message_type == "text":
            content = json.loads(event.message.content)["text"]
            print(f"\n=== 收到新消息 ===")
            # print(f"会话类型: {'单聊' if chat_type == 'p2p' else '群聊'}")
            # print(f"发送者 ID: {sender_id}")
            print(f"消息内容: {content}")
            # print(f"消息 ID: {message_id}")
            time.sleep(10)
            # 发送回复消息
            reply_content = f"已收到你的消息: {content}"
            # send_message(chat_id, reply_content, chat_type)

            # 发送消息给手机
            send_feishu_message(message_content=content)
        else:
            print(f"\n=== 收到不支持的消息类型 ===")
            print(f"类型: {message_type}, 消息 ID: {message_id}")

    except Exception as e:
        print(f"处理消息时出错: {str(e)}")

def do_p2_im_message_receive_v1(data: lark.im.v1.P2ImMessageReceiveV1) -> None:
    event = data.event
    message_type = event.message.message_type
    if message_type == "text":
        content = json.loads(event.message.content)["text"]
        print(f"\n=== 🤖收到新消息 ===")
        # print(f"会话类型: {'单聊' if chat_type == 'p2p' else '群聊'}")
        # print(f"发送者 ID: {sender_id}")
        print(f"🤖消息内容: {content}")
        asyncio.create_task(task_runner.run_all_tasks(content))
    # print(f'[ do_p2_im_message_receive_v1 access ], data: {lark.JSON.marshal(data, indent=4)}')
# --------------------------
# 处理机器人进入单聊事件时发送欢迎消息
# --------------------------
# def handle_bot_enter_p2p(data: lark.CustomizedEvent) -> None:
#     try:
#         print(f"\n=== 机器人进入单聊会话 ===")
#         # 提取会话ID
#         chat_id = data.event.get("chat_id")
#         if chat_id:
#             # 发送欢迎消息
#             welcome_msg = "你好！我是你的助手，有什么可以帮助你的吗？"
#             send_message(chat_id, welcome_msg)
#
#         print(f"事件数据: {lark.JSON.marshal(data, indent=2)}")
#     except Exception as e:
#         print(f"处理进入单聊事件时出错: {str(e)}")
#

# --------------------------
# 注册所有事件处理器
# --------------------------
event_handler = (lark.EventDispatcherHandler.builder("", "")
                 # .register_p2_im_message_receive_v1(handle_message)
                .register_p2_im_message_receive_v1(do_p2_im_message_receive_v1)
                 # .register_p2_customized_event("im.chat.access_event.bot_p2p_chat_entered_v1",
                 #    handle_bot_enter_p2p)
                 .build())


# --------------------------
# 独立函数，机器人给手机发送消息用的
# --------------------------
def send_feishu_message(message_content="旺旺", msg_type="text"):
    APP_ID = "cli_a8104951b66b900c"  # 从开发者后台获取
    APP_SECRET = "0AwayvK6wJMxjuwcDl8B2c1r5qPybEaw"  # 从开发者后台获取
    RECEIVE_ID = "ou_3777a45bad41aeb30508665ba04678db"  # 接收者ID（用户ID或群组ID）这个id是在发送消息开放文旦中 右边查询参数找到的，每个用户一个
    # MESSAGE_CONTENT = "旺旺"  # 消息内容
    def get_app_access_token(app_id, app_secret):
        """获取飞书自建应用的app_access_token和tenant_access_token"""
        url = "https://open.feishu.cn/open-apis/auth/v3/app_access_token/internal"
        headers = {"Content-Type": "application/json; charset=utf-8"}
        payload = {"app_id": app_id, "app_secret": app_secret}

        try:
            response = requests.post(
                url=url,
                headers=headers,
                data=json.dumps(payload)
            )
            result = response.json()

            if result.get("code") == 0:
                return {
                    "success": True,
                    "app_access_token": result.get("app_access_token"),
                    "tenant_access_token": result.get("tenant_access_token"),
                    "expire": result.get("expire")
                }
            else:
                return {
                    "success": False,
                    "error_code": result.get("code"),
                    "error_msg": result.get("msg")
                }

        except requests.exceptions.RequestException as e:
            return {
                "success": False,
                "error_msg": f"网络请求异常: {str(e)}"
            }

    # 1. 获取token（可选，SDK内部会自动处理token获取）
    token_info = get_app_access_token(APP_ID, APP_SECRET)
    if token_info["success"]:
        pass
        print("获取Token成功:")
        print(f"app_access_token: {token_info['app_access_token']}")
        print(f"有效期: {token_info['expire']}秒")
    else:
        print(f"获取Token失败: {token_info['error_msg']}")

    # 2. 发送消息
    # print("\n🤖开始发送消息...")
    # send_feishu_message(
    #     app_id=APP_ID,
    #     app_secret=APP_SECRET,
    #     receive_id=RECEIVE_ID,
    #     message_content=MESSAGE_CONTENT
    # )

    # 创建client
    client = lark.Client.builder() \
        .app_id(APP_ID) \
        .app_secret(APP_SECRET) \
        .log_level(lark.LogLevel.ERROR) \
        .build()
    content = f'{{"text": "{message_content}"}}'
    # 构造请求对象
    request: CreateMessageRequest = CreateMessageRequest.builder() \
        .receive_id_type("open_id") \
        .request_body(CreateMessageRequestBody.builder()
                      .receive_id(RECEIVE_ID)
                      .msg_type(msg_type)
                      .content(content)
                      .build()) \
        .build()

    # 发起请求
    response: CreateMessageResponse = client.im.v1.message.create(request)

    # 处理失败返回
    if not response.success():
        lark.logger.error(
            f"client.im.v1.message.create failed, code: {response.code}, msg: {response.msg}, log_id: {response.get_log_id()}, resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}")
        return

    # 处理业务结果
    # lark.logger.info(lark.JSON.marshal(response.data, indent=4))
    print(f"🤖:{message_content}")


# --------------------------
# 启动长连接客户端
# --------------------------
def main():
    # 初始化长连接客户端（用于接收消息）
    client = lark.ws.Client(
        app_id=APP_ID,
        app_secret=APP_SECRET,
        event_handler=event_handler,
        log_level=lark.LogLevel.INFO  # 日志级别：INFO/DEBUG
    )

    print("机器人已启动，等待接收消息...（按 Ctrl+C 停止）")
    client.start()  # 启动长连接，持续监听事件
    # send_message("oc_66cebc864299922073d58b421f01cd13", "123", "p2p")


if __name__ == "__main__":
    main()



import os
import time
import sys
"""
防止同时使用一个程序的锁
from mutex_lock import SimpleLock
browser_lock = SimpleLock(lock_file="browser_operation.lock")
browser_lock.lock():  # 上锁
browser_lock.unlock()  # 确保释放锁



browser_lock.lock(timeout=30):  # 上锁  timeout也可以不写   最多等待30秒



"""
try:
    # 尝试导入Windows的锁模块
    import msvcrt
except ImportError:
    msvcrt = None
try:
    # 尝试导入Unix的锁模块
    import fcntl
except ImportError:
    fcntl = None


class SimpleLock:
    def __init__(self, lock_file="resource.lock"):
        """初始化锁对象，跨平台支持"""
        self.lock_file = lock_file
        self.file_handle = None

    def lock(self, timeout=None, check_interval=1):
        """上锁操作，支持跨平台

        :param timeout: 超时时间(秒)，None表示无限等待
        :param check_interval: 检查间隔时间(秒)
        :return: 是否成功获取锁
        """
        start_time = time.time()

        while True:
            # 检查是否超时
            if timeout is not None and (time.time() - start_time) > timeout:
                return False

            try:
                # 尝试创建并锁定文件
                self.file_handle = open(self.lock_file, 'w')

                # 根据不同操作系统使用不同的锁机制
                if sys.platform.startswith('win') and msvcrt:
                    # Windows系统
                    msvcrt.locking(self.file_handle.fileno(), msvcrt.LK_NBLCK, 1)
                elif fcntl:
                    # Unix/Linux/Mac系统
                    fcntl.flock(self.file_handle, fcntl.LOCK_EX | fcntl.LOCK_NB)
                else:
                    # 不支持文件锁的系统，使用简单的文件存在性检查
                    print("警告: 系统不支持文件锁，使用基础文件检查模式")

                return True

            except (BlockingIOError, PermissionError, IOError):
                # 锁已被占用，关闭文件句柄
                if self.file_handle:
                    self.file_handle.close()
                    self.file_handle = None
                print("发现被占用")
                # 等待一段时间后重试
                time.sleep(check_interval)
            except Exception as e:
                print(f"上锁失败: {e}")
                if self.file_handle:
                    self.file_handle.close()
                    self.file_handle = None
                return False

    def unlock(self):
        """解锁操作，释放资源"""
        if self.file_handle:
            try:
                # 释放文件锁
                if sys.platform.startswith('win') and msvcrt:
                    # Windows系统解锁
                    msvcrt.locking(self.file_handle.fileno(), msvcrt.LK_UNLCK, 1)
                elif fcntl:
                    # Unix系统解锁
                    fcntl.flock(self.file_handle, fcntl.LOCK_UN)

                self.file_handle.close()
            except Exception as e:
                print(f"解锁失败: {e}")
            finally:
                self.file_handle = None

        # 删除锁文件
        if os.path.exists(self.lock_file):
            try:
                os.remove(self.lock_file)
            except Exception as e:
                print(f"删除锁文件失败: {e}")



#!/usr/bin/env python
#coding=utf-8
# author:wade
# contact: 317909531@qq.com
# datetime:2021/4/5 22:14
#wo  ai ni

"""
文件说明：
方便直接使用模拟浏览器进行网页操作，ReuseBrowser 类完成了对于已经打开的网页进行操作的功能，再也不用重新启动网页测试了
driver.find_element_by_id(‘id’)
driver.find_element_by_xpath('xpath')
driver.find_element_by_link_text('link_text')
driver.find_element_by_partial_link_text('partial_link_text')
driver.find_element_by_name('name')
driver.find_element_by_tag_name('tag_name')
driver.find_element_by_class_name('class_name')
driver.find_element_by_css_selector('css_selector')
"""

from selenium import webdriver
from selenium.webdriver.chrome import options
from selenium.webdriver.common.by import By
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver import ActionChains
from selenium.webdriver.common.keys import Keys
from selenium.webdriver import Remote
import pickle

class ReuseBrowser(Remote):
    """专门用来保证复用一个浏览器的类，超级好用，2022年8月亲测
        记录一个bug，我在2022年的秋天，我使用了    selenium 的4.4版本，
        我打算同时运行多个程序使用同一个网页，而调试的时候没事，exe的时候就会出现找不到就旧的窗口
        所以，我查了是因为 Exception是：can't set attribute 怎么解决呢？还不能运行的 selenium 版本改成 3.141.0 就可以了 不要最新的

        pip install selenium==3.141.0
        """

    def __init__(self, command_executor, session_id):

        self.r_session_id = session_id
        Remote.__init__(self, command_executor=command_executor, desired_capabilities={})

    def start_session(self, desired_capabilities, browser_profile=None):

        capabilities = {'desiredCapabilities': {}, 'requiredCapabilities': {}}
        for k, v in desired_capabilities.items():
            if k not in ('desiredCapabilities', 'requiredCapabilities'):
                capabilities['desiredCapabilities'][k] = v
            else:
                capabilities[k].update(v)
        if browser_profile:
            capabilities['desiredCapabilities']['firefox_profile'] = browser_profile.encoded

        self.w3c = "specificationLevel" in self.capabilities
        self.capabilities = options.Options().to_capabilities()
        self.session_id = self.r_session_id
        self.w3c = True


def get_wade_driver():
    """打开浏览器，保存浏览器地址 到web.data"""
    try:
        print('准备链接旧窗口')
        with open('web.data','rb') as f:
            webdata = pickle.load(f)
        print("旧窗口：",webdata)
        driver = ReuseBrowser(webdata[0], webdata[1])
        print(driver.window_handles)
        driver.switch_to.window(driver.window_handles[-1])  #切换到最新得页面，保证永远页面永远有效
        # exit()
        # driver = ReuseBrowser("http://127.0.0.1:54885", "47507182d69d578585e80c66d28d35a5")
        print(driver.title)  #利用获取title来判断是否有浏览器程序，也不会打扰到当前页面

    except Exception as e:
        print(e)
        print(f'error file:{e.__traceback__.tb_frame.f_globals["__file__"]}')
        print(f"error line:{e.__traceback__.tb_lineno}")
        print('未检测到窗口，初始化新窗口')
        url = 'https://channels.weixin.qq.com/post/create'
        option = webdriver.ChromeOptions()
        # # option.add_argument('--headless')  # 开启无界面模式
        # # option.add_argument('--disable-gpu')  # 禁用显卡
        option.add_experimental_option('excludeSwitches', ['enable-automation'])  # 禁止js反爬虫
        option.add_argument('--disable-blink-features=AutomationControlled')
        # 配置浏览器类型
        # prefs = {"profile.managed_default_content_settings.images": 2}  #禁止加载图片
        # option.add_experimental_option("prefs", prefs)  #禁止加载图片
        # # 设置cmd窗口不弹出来
        driver = webdriver.Chrome(executable_path='chromedriver', chrome_options=option)

        weblist = [driver.command_executor._url,driver.session_id]
        with open('web.data','wb') as f:
            pickle.dump(weblist,f)
        print('保存浏览器句柄,','创建的新窗口ID为：',weblist ,'已经保存到webdata中')
        # while True:
        #     print(driver.window_handles)
    return driver




# 等待某个元素加载成功
def waitItem(driver,time,className):
    WebDriverWait(driver, time).until(
        EC.presence_of_element_located((By.CLASS_NAME, className)))

def parstCookies2dict(driver):
    """将driver获取得cookie转换为字典格式方便提取"""
    cookie_parse = dict()
    for ck in driver.get_cookies():
        cookie_parse[ck['name']] = ck['value']
    cookie_Dict = cookie_parse
    return cookie_Dict
def parstCookies2str(driver):
    """将cookie转换为字符串  xxx=aaa;bbb=ccc;这种格式可以方便request调用"""
    cookie = driver.get_cookies()
    cookie_parse = dict()
    for ck in cookie:
        cookie_parse[ck['name']] = ck['value']
        # 将字典拼成字符串
    cookies = ''.join([str(k) + '=' + str(v) + ';' for k, v in cookie_parse.items()])
    return cookies
if __name__ == '__main__':
    driver = get_wade_driver()
    driver.get('http://www.tbzhu.com')
    # driver.find_element_by_class_name()






import time

import wmi
from wadeTools import wadeTools_Print
import ctypes

def is_locked():
    ''' 用法
        from wadeTools import wadeTools_getSystemInfo
        while wadeTools_getSystemInfo.is_locked(): #如果锁屏的话就是True
        wadePrint("电脑锁屏，暂停工作，等待10秒后重试.....")
        time.sleep(10)
    '''
    hwnd = ctypes.windll.user32.GetForegroundWindow()
    return hwnd == 0  # 锁屏时返回True

def get_mac_address():
    try:
        c = wmi.WMI()
        for interface in c.Win32_NetworkAdapterConfiguration(IPEnabled=True):
            return interface.MACAddress
    except:
        return "获取MAC地址失败"

def get_system_manufacturer():
    try:
        c = wmi.WMI()
        system_info = c.Win32_ComputerSystem()[0]
        return system_info.Manufacturer
    except:
        return "获取系统制造商信息失败"

def get_system_model():
    try:
        c = wmi.WMI()
        system_info = c.Win32_ComputerSystem()[0]
        return system_info.Model
    except:
        return "获取系统型号失败"

def get_operating_system():
    try:
        c = wmi.WMI()
        os_info = c.Win32_OperatingSystem()[0]
        return os_info.Caption
    except:
        return "获取操作系统信息失败"

if __name__ == "__main__":
    # mac_address = get_mac_address()
    # system_manufacturer = get_system_manufacturer()
    # system_model = get_system_model()
    # operating_system = get_operating_system()
    # wadeTools_Print.wadeBluePrint("狮子庙中学统计软件正版化统计：以下是你系统信息，选中后右键可以复制:\n")
    # print("MAC地址:", mac_address)
    # print("计算机品牌:", f"{system_manufacturer} {system_model}")
    # print("操作系统:", operating_system)
    # input("按回车键退出程序...")
    while True:
        print(is_locked())
        time.sleep(1)


# -- coding: utf-8 --
# 作者:shenhuawade
"""说明文档：
20241208复制到剪切板
"""
from win32clipboard import OpenClipboard, CloseClipboard, EmptyClipboard, SetClipboardData, RegisterClipboardFormat
import ctypes
def insertClicpboard(insertHtml):
    """
    复制到剪切板主函数
    :param insertHtml:
    :return:
    """
    # insertHtml = "<p>123</p>"  # 待插入的文本
    # 写入数据
    template = f"""Version:0.9
    StartHTML:0000000001
    EndHTML:0000000000
    StartFragment:0000000000
    EndFragment:0000000000
    <html>
    <body>
    <!--StartFragment-->{insertHtml}</br><!--EndFragment-->
    </body>
    </html>"""
    # 定义要申请的内存大小
    size = 10000 + len(template)

    # 使用 ctypes.create_string_buffer()函数来申请内存空间
    buffer = ctypes.create_string_buffer(size)

    buffer.raw = f"{template}".encode('utf-8')
    # 读取数据
    # data = buffer.raw
    # # 打印数据
    # print(data)
    OpenClipboard()
    EmptyClipboard()
    cfid = RegisterClipboardFormat("HTML Format")
    SetClipboardData(cfid, buffer.raw)
    CloseClipboard()

if __name__ == '__main__':
    html = '''<p><img src="http://img30.360buyimg.com/shaidan/s720x540_jfs/t1/136628/3/14287/1924070/5f9d8058Ee25048a4/937e211cf8b0bf97.jpg" alt=""></p><ul><li>宝妈群里都在推荐好奇的皇家铂金御裤果断中草下单收到货真的非常满意颜值非常高包装很精美龙纹非常吸晶尿裤很柔软手感舒适保护宝宝嫩嫩的pp而且尿裤很薄内含3D透氧层一晚上没换宝宝的pp都没有红吸量也不错也没有漏尿的情况出现超级赞！</li></ul><hr><h2 style="font-size: 1.2em;line-height: 1.5;font-weight: 600;">二、<span>【文章标题】</span>用户关心的问题</h2><div><ol><li>问题：这款会红屁屁吗<p>♥好奇皇家御裤很透气的，正常来说是不会红屁屁的，但是也得勤换洗，不然再透气的纸尿裤也会红屁屁。</p></li><li>问题：宝妈们，这款的NB码柔软吗，是薄款的吗，预产期7月份。<p>♥好奇皇家御裤裸感芯0.2cm，挺轻薄透气的，七月份天气很热，挺适合的。</p></li><li>问题：会不会觉得有点硬<p>♥不硬啊，特别软</p></li><li>问题：皇家铂金和大王天使哪个好用？谢谢<p>♥没用过大王的，一直都是用的好奇皇家御裤，挺轻薄透气的，孩子用了也没红屁屁等问题。</p></li><li>问题：请问现在宝宝还有10天出月子现在8斤8两，出月子想用纸尿裤，现在囤货买多大合适？<p>♥再用几片NB码，可以开始囤S码了，但别囤太多</p></li><li>问题：皇家御裤和小桃裤哪个更薄更好用？<p>♥小桃裤比较薄，但因为冬天我选择了皇家</p></li><li>问题：84片够用多久？<p>♥半个月左右</p></li><li>问题：容易红屁股吗？<p>♥我崽不会红，挺柔软的</p></li><li>问题：皇家铂金装有味道吗<p>♥有味呢！腰那里味道很大</p></li><li>问题：是不是容易侧漏啊<p>♥我家的用了这么久没有一片侧漏，放心买吧</p></li></ol></div><hr><h2 style="font-size: 1.2em;line-height: 1.5;font-weight: 600;">三、<span>【文章标题】</span>配置参数、类型</h2><hr><p><img src="http://img30.360buyimg.com/shaidan/s720x540_jfs/t1/118437/14/14760/63573/5f365302E10f8570a/8742e0f8212b5826.jpg" alt=""></p><hr><h2 style="font-size: 1.2em;line-height: 1.5;font-weight: 600;">四'''
    insertClicpboard(html)

    # insertClicpboard("""<p>nihao</p><img src="https://p6-flow-imagex-sign.byteimg.com/ocean-cloud-tos/FileBizType.BIZ_BOT_ICON/3251350_1697011106512121056.png~tplv-a9rns2rl98-icon-tiny.png?rk3s=9956f44f&x-expires=1714738220&x-signature=wR9a%2F0Q%2BNCr2i0bBiJ535ZEJ0zc%3D" alt="图片描述" />""")


#!/usr/bin/env python
# coding=utf-8
'''自动创建文件目录'''
from wadeTools.wadeTools_Print import wadePrint

'''文件移动'''
import os
import shutil


def checkFilePath(relativePath, filename=None):
    path = os.getcwd()
    path = os.path.join(path, relativePath)
    if not os.path.exists(path):
        os.makedirs(path)
    if filename:
        with open(os.path.join(os.getcwd(), path, filename), 'w+', encoding='utf-8') as f:
            f.write("")


import os
import shutil


def remove_file(filename, old_dir, new_dir):
    """
    注释： 实现将一个文件从一个文件夹 移动到另一个目标文件夹，old_dir, new_dir都采用的是相对路径
    :param filename:  需要移动的文件名
    :param old_dir:   旧文件夹（相对路径）
    :param new_dir:   需要移动到新文件夹（相对路径）
    :return:
    """
    try:
        checkFilePath(relativePath=old_dir)
        checkFilePath(relativePath=new_dir)
        file_path = old_dir + '/' + filename
        target_path = os.path.join(new_dir, filename)
        if os.path.exists(target_path):
            # 直接删除目标路径下已存在的同名文件
            os.remove(target_path)
        shutil.copy2(file_path, new_dir)
        os.remove(file_path)
    except Exception as e:
        wadePrint(e)
        pass


if __name__ == '__main__':
    # checkFilePath(relativePath='./saveFile/')
    # checkFilePath(relativePath='./成品/')
    # remove_file(filename='1.py',old_dir=r"./saveFile/", new_dir=r"./成品/")

    print(os.path.abspath('.'))
    print(os.getcwd())
    print(os.path.abspath('./saveFile'))
    print(os.path.abspath('./成品'))
    print(os.path.abspath('../README.md'))



import requests

import urllib.parse

from requests.exceptions import RequestException

from urllib.parse import urljoin

from lxml import etree
import re
import json

# 百度搜索接口

def format_url(url, params: dict=None) -> str:
    query_str = urllib.parse.urlencode(params)
    return f'{ url }?{ query_str }'

def get_url(keyword):
    params = {
        'wd': str(keyword)
    }
    url = "https://www.baidu.com/s"
    url = format_url(url, params)
    # print(url)

    return url

def get_page(url):
    try:
        headers = {
            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36',
            'accept-language': 'zh-CN,zh;q=0.9',
            'cache-control': 'max-age=0',
            'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8'
        }
        response = requests.get(url=url,headers=headers)
        # 更改编码方式，否则会出现乱码的情况
        response.encoding = "utf-8"
        print(response.status_code)
        # print(response.text)
        if response.status_code == 200:
            saveHtml(response.content)
            # print(response.text)
            return response.text
        return None
    except RequestException:
        return None

def saveHtml(content):
    with open('百度get.html','wb') as f:
        f.write(content)
def parse_page(url,page):

    for i in range(1,int(page)+1):
        print("正在爬取第{}页....".format(i))
        title = ""
        sub_url = ""
        abstract = ""
        flag = 11
        if i == 1:
            flag = 10
        html = get_page(url)
        # print(html)
        content = etree.HTML(html)
        for j in range(1,flag):
            data = {}
            res_title = content.xpath('//*[@id="%d"]/h3/a' % ((i - 1) * 10 + j))
            if res_title:
                title = res_title[0].xpath('string(.)')

            sub_url = content.xpath('//*[@id="%d"]/h3/a/@href' % ((i - 1) * 10 + j))
            if sub_url:
                sub_url = sub_url[0]

            res_abstract = content.xpath('//*[@id="%d"]/div[@class="c-abstract"]'%((i-1)*10+j))
            if res_abstract:
                abstract = res_abstract[0].xpath('string(.)')
            else:
                res_abstract = content.xpath('//*[@id="%d"]/div/div[2]/div[@class="c-abstract"]'%((i-1)*10+j))
                if res_abstract:
                    abstract = res_abstract[0].xpath('string(.)')
                    # res_abstract = content.xpath('//*[@id="%d"]/div/div[2]/p[1]'%((i-1)*10+j))
            # if not abstract:
            #     abstract = content.xpath('//*[@id="%d"]/div/div[2]/p[1]'%((i-1)*10+j))[0].xpath('string(.)')
            data['title'] = title
            data['sub_url'] = sub_url
            data['abstract'] = abstract


            rel_url = content.xpath('//*[@id="page"]/a[{}]/@href'.format(flag))
            if rel_url:
                url = urljoin(url, rel_url[0])
            else:
                print("无更多页面！～")
                return
            yield data

def main():
    keyword = input("输入关键字:")
    page = input("输入查找页数:")
    url = get_url(keyword)

    results = parse_page(url,page)
    # print(results)
    # 写入文件
    file = open("data.json", 'w+', encoding='utf-8')

    for result in results:
        print(result)
        file.write(json.dumps(result, indent=2, ensure_ascii=False))

if __name__ == '__main__':
    main()


class Error_info(Exception):

    #提醒，不影响主程序
    def __init__(self, value):
        self.value = value

    def __str__(self):
        return repr(self.value)
class Error_break(Exception):

    #停止程序
    def __init__(self, value):
        self.value = value

    def __str__(self):
        return repr(self.value)
class Error_continue(Exception):
    #跳过循环
    def __init__(self, value):
        self.value = value

    def __str__(self):
        return repr(self.value)

class Error_notAdd(Exception):
    #跳过循环
    def __init__(self, value):
        self.value = value

    def __str__(self):
        return repr(self.value)


import winreg
import ctypes
# import PySimpleGUI as sg
# 设置系统代理，取消系统代理
# 打开注册表键
import requests

INTERNET_SETTINGS = winreg.OpenKey(winreg.HKEY_CURRENT_USER,
    r'Software\Microsoft\Windows\CurrentVersion\Internet Settings',
    0, winreg.KEY_ALL_ACCESS)

# 设置刷新
INTERNET_OPTION_REFRESH = 37
INTERNET_OPTION_SETTINGS_CHANGED = 39
internet_set_option = ctypes.windll.Wininet.InternetSetOptionW

def set_key(name, value):
    # 修改键值
    _, reg_type = winreg.QueryValueEx(INTERNET_SETTINGS, name)
    winreg.SetValueEx(INTERNET_SETTINGS, name, 0, reg_type, value)

def open_proxy(proxy_server):
    # 启用代理
    set_key('ProxyEnable', 1) # 启用
    set_key('ProxyServer', proxy_server) # 设置代理服务器
    internet_set_option(0, INTERNET_OPTION_REFRESH, 0, 0)
    internet_set_option(0, INTERNET_OPTION_SETTINGS_CHANGED, 0, 0)

def closed_proxy():
    # 禁用系统的代理
    set_key('ProxyEnable', 0) # 禁用
    internet_set_option(0, INTERNET_OPTION_REFRESH, 0, 0)
    internet_set_option(0, INTERNET_OPTION_SETTINGS_CHANGED, 0, 0)
# 启用代理并设置代理服务器为 'http://proxy.example.com:8080'
# enable_proxy('http://proxy.example.com:8080')

def changeAgent():
    # 设置系统代理
    global proxies
    url = 'https://proxy.qg.net/allocate?Key=9XFOUQ5B&Num=1&AreaId=&DataFormat=txt&DataSeparator=%5Cr%5Cn&Detail=0'
    html = requests.get(url,timeout=10)
    print('切换新代理：',html.text)

    key = '9XFOUQ5B'
    passwd = '2F5079EA8A6B'
    proxy = f'http://{key}:{passwd}@{html.text}'
    proxy = html.text

    # proxies = {
    #     "http": proxy,
    #     "https": proxy
    # }
    return proxy
def changeAgentButton(): #  切换系统代理按钮


    sg.theme('DarkAmber')  # 设置当前主题色
    # 界面布局，将会按照列表顺序从上往下依次排列，二级列表中，从左往右依此排列
    layout = [[sg.B("切换代理", key="切换代理"),sg.B("关闭代理", key="关闭代理"),sg.I("状态",key="Status")]
              ,[sg.B("查看当前地址", key="查看当前地址"),sg.T("地区状态",key="地区状态")]]

    def my_long_operation():
        print("点击按钮")
        closed_proxy() # 关闭代理
        newAgent = changeAgent()
        windows['Status'].update(f"系统代理:{newAgent}")
        open_proxy(newAgent)  # 开启代理

    def getAddressNow():  # 打开查看ip地址
        html = requests.get("http://myip.ipip.net/")
        print(html.text)
        windows['地区状态'].update(f"区域:{html.text}")

    # 创造窗口
    windows = sg.Window('代理窗口', layout, location=(0, 0), font=("宋体", 10))

    while True:
        event, values = windows.Read()
        if event == sg.WIN_CLOSED or event == 'Exit':
            print('代理窗口关闭')
            break
        if event == '切换代理':  # 登录按钮
            windows.perform_long_operation(my_long_operation, '-finish-')
        if event == '查看当前地址':  # 登录按钮
            windows.perform_long_operation(getAddressNow, '-finish-')
        if event == '关闭代理':  # 登录按钮
            windows['Status'].update(f"系统代理已关闭")
            windows.perform_long_operation(closed_proxy(), '-finish-')
            windows['地区状态'].update(f"区域:当前本机区域")
    windows.close()

def startAgentThread():
    # 多进程，因为tk不支持在多线程中开启
    from concurrent.futures import ProcessPoolExecutor
    executor = ProcessPoolExecutor(max_workers=5)
    executor.submit(changeAgentButton)
    # executor.shutdown(wait=False)
    # with ProcessPoolExecutor(max_workers=5) as executor:
    #     executor.submit(changeAgentButton)




    # import threading
    # task1 = threading.Thread(target=changeAgentButton)
    # task1.start()
if __name__ == '__main__':
    # changeAgentButton() # 是窗口函数
    startAgentThread()  # 是在进程里开启一个窗口函数
    # changeAgentButton()  # 是窗口函数
    # getAddressNow()
    # disable_proxy() # 关闭代理
    # print(changeAgent())
    # enable_proxy(changeAgent())  # 开启代理



#!/usr/bin/env python
# coding=utf-8
# author:wade
# contact: 317909531@qq.com
# datetime:2021/1/2 21:41

"""
文件说明：基础类，生成模板使用
"""
import random


# 构造文章的基础,输入基本信息，构造出评论列表和图片列表
import time

from wadeTools.wadeTools_JDAPI import JDSpider
from wadeTools import wadeTools_baiduPost_API,wadeTools_ReadAndWrite
from wadeTools import wadeTools_error
from wadeTools.wadeTools_Print import wadePrint
#该类废弃
# class Tools_Template(object):
#     # 废弃
#     def __init__(self, title, commentList, imgList, itemURL, shopUrl, **kwargs):
#
#         """
#         本函数需要有6条评论和6个图片才能运行，在调用前需要做好判断
#
#         :param title: 生成文案的标题
#         :param commentList: 生成文案的评论列表
#         :param imgList: 生成文案的图片列表
#         :param itemURL: 自己的商品推广链接
#         :param shopUrl: 自己的店铺推广链接
#         :return 产出文章
#         :templateFactory_forDiscuz Return:主句字符串和评论列表
#         """
#         random.shuffle(commentList)
#         random.shuffle(imgList)
#         self.title = title
#         self.commentList = commentList
#         self.imgList = imgList
#         self.itemURL = itemURL
#         self.shopUrl = shopUrl
#         self.kwargs = kwargs
#         self.ifRun = True
#         self.pinglunList = []  # 论坛跟帖专用
#         self.content = ''  # 论坛跟帖专用
#         wadePrint(self.kwargs)
#
#     def wordJoin_imgJoin(self):
#         # 这个函数是处理的核心，输出的内容是一段一段的，[一组话，加上几张配图],后边只需要判断非空就行了
#         words = []
#         imgs = []
#         countWORD = 0
#
#         P = [1, 1, 1, 1, 1, 1, 1, 1]  # 文章段落排版，如果没有图片了，就不再进行编入
#         I = [1, 1, 1, 1, 1, 1, 1, 1]
#         # 第一次循环检查需求条数是否超出评论总量，如果不超出，就生成
#         # 第二次循环检查需求条数是否超出评论剩余，如果不超出，就生成
#         for runTime, num in enumerate(P):
#             if P[runTime] <= len(self.commentList) - countWORD:  # 检查组合后剩余条数
#                 # 根据要求进行循环
#                 # wadePrint('开始使用', (countWORD, countWORD + P[runTime]))
#                 words.append(''.join(self.commentList[countWORD:countWORD + P[runTime]]))  # 第0段
#                 # 统计已经用掉多少条
#                 countWORD = countWORD + num
#                 # wadePrint('剩余条数', len(self.commentList) - countWORD)
#
#
#         # 验证生产环境
#         articleList = []
#         imgLists = []
#         imgLists = self.imgList[2:].copy()
#         """
#             0 one
#             1 two
#             2 three
#         """
#         for cout, i in enumerate(words,start=0):
#             imgss = []
#             if len(I) > cout:
#                 # wadePrint(len(I),cout)
#
#                 for item in range(I[cout]):
#                     if imgLists != []:
#                         imgss.append(imgLists.pop(0))
#                     else:
#                         imgss = []
#             else:
#                 mgss = []
#             articleList.append([i, imgss])
#         return articleList
#
#     def templateFactory_forDiscuz(self,longUrl):
#         self.words = self.wordJoin_imgJoin()
#
#         # 主要内容：1段话，2张图片
#         # 如果只有一句话，没有图： 如果只有一句话 一张图：如果只有一句话2张图，如果只有1句话 3张图，如果只有2句话
#
#         if len(self.words) > 2 and len(self.imgList) >= 2:
#             self.content = f'''[font=&quot;]{self.words[0][0]}[/font]
#         [font=&quot;][b][size=4]关于产品质量怎么样，以下供参考：[/size][/b]
#         [/font][b][size=4][color=#ff0000]【千万不要被骗了】查看官网最新报价[/color][/size][/b][font=&quot;][color=#ff0000][size=4][b]：[/b][/size][/color][/font][font=arial, Tahoma, Verdana, STHeiTi, simsun, sans-serif, 宋体][size=5][color=#00bfff][b][url={longUrl}]点击查看[/url][/b][/color][/size][/font]
#         [font=&quot;][color=#ff0000][/color][/font][font=&quot;][color=#ff0000][size=4][b]产品性能，使用感受综合评测：[/b][/size][/color][/font][font=arial, Tahoma, Verdana, STHeiTi, simsun, sans-serif, 宋体][size=5][color=#00bfff][b][url={longUrl}]点击查看[/url][/b][/color][/size][/font]
#         [img=400,400]{self.imgList[0]}[/img]
#         [img=400,400]{self.imgList[1]}[/img]'''
#
#             for index, item in enumerate(self.words, start=1):
#                 pinglunWord = f'''[font=&quot]{item[0]}[/font]
#                 '''
#                 for imgRealLink in item[1]:
#                     pinglunWord = pinglunWord+f'''[img]{imgRealLink}[/img]
#                     '''
#                 self.pinglunList.append(pinglunWord)
#                 del pinglunWord
#
#             return self.content, self.pinglunList
#         else:
#             return [], []
#
#     def templateFactory_forQb(self,jdid,shopid,shopname,skuName,item_MainImg,item_price,shotUrl, longUrl):
#         self.words = self.wordJoin_imgJoin()
#         # 京东id/店铺id/店铺名称/产品名称/产品主图/产品价格/////
#         """返回self.content 字符串"""
#         if self.words != []:
#             self.content = f'''{self.words[0][0]}
#                         <p><strong><span style="font-size: big;color: black;">【千万不要被骗了】点击下方链接查看官网最新报价</span></strong></p>
#         <div>
#         <a style="background-color: #f6f6f6;
#           display: block;
#           border-radius: 8px;
#           box-shadow:0px 0px 10px 5px #aaa;
#           overflow: hidden;
#           color: inherit;
#           margin: 1em auto;
#           max-width: 100%;
#           min-height: 88px;
#           position: relative;
#           text-decoration: none;
#           width: 390px;
#           z-index: 0;"
#            href="{longUrl}">
#             <div style="-webkit-box-align: stretch;
#                 -ms-flex-align: stretch;
#                 align-items: stretch;
#                 position: relative;
#                 display: -webkit-box;
#                 display: -ms-flexbox;
#                 display: flex;
#                 overflow: hidden;
#                 max-width: 400px;
#                 min-height: 88px;">
#                 <div style="-webkit-box-sizing: border-box;
#                       box-sizing: border-box;
#                       width: 100%;
#                       padding: 14px;
#                       z-index: 2;
#                       -webkit-box-align: stretch;
#                       -ms-flex-align: stretch;
#                       align-items: stretch;
#                       position: relative;
#                       display: -webkit-box;
#                       display: -ms-flexbox;
#                       display: flex;">
#                     <div style="flex-shrink: 0;
#                             overflow: hidden;
#                             position: relative;
#                             border-radius: 6px;
#                             height: 100px;
#                             width: 100px;">
#                         <img style="height: 100%;
#                                   width: 100%;" src="{item_MainImg}"
#                              alt="">
#                     </div>
#                     <div style="
#                             display: -webkit-box;
#                             display: -ms-flexbox;
#                             display: flex;
#                             -webkit-box-orient: vertical;
#                             -webkit-box-direction: normal;
#                             -ms-flex-direction: column;
#                             flex-direction: column;
#                             -webkit-box-flex: 1;
#                             -ms-flex-positive: 1;
#                             flex-grow: 1;
#                             margin-left: 12px;
#                             overflow: hidden;">
#                         <div style="display: flex;-webkit-box-align: center;
#                                   -ms-flex-align: center;
#                                   align-items: center;
#                                   -webkit-box-pack: justify;
#                                   -ms-flex-pack: justify;
#                                   justify-content: space-between;">
#                             <div style="color: #121212;
#                                         font-size: 16px;
#                                         line-height: 20px;
#                                         max-height: 40px;
#                                         font-weight: 600;
#                                         font-synthesis: style;
#                                         display: -webkit-box;
#                                         text-overflow: ellipsis;
#                                         overflow: hidden;
#                                         -webkit-line-clamp: 2;
#                                         -webkit-box-orient: vertical;">{skuName}
#                             </div>
#                         </div>
#                         <div style="color: #646464;
#                               font-size: 12px;
#                               line-height: 17px;
#                               margin-top: 5px;
#                               font-weight: 600;
#                               font-synthesis: style;"> 京 东
#                         </div>
#                         <div style="display: -webkit-box;
#                               display: -ms-flexbox;
#                               display: flex;
#                               -webkit-box-align: end;
#                               -ms-flex-align: end;
#                               align-items: flex-end;
#                               margin-top: auto;">
#                             <div style="margin-right: auto;display: block;">
#                                 <div class="MCNLinkCard-price" style="-webkit-box-align: center;
#                               -ms-flex-align: center;
#                               align-items: center;
#                               color: #ff7955;
#                               display: -webkit-box;
#                               display: -ms-flexbox;
#                               display: flex;
#                               font-size: 16px;
#                               font-weight: 500;
#                               line-height: 18px;
#                               margin-right: auto;">
#                                     <span>¥ {item_price}</span></div>
#                             </div>
#                             <div style="display: -webkit-box;
#             display: -ms-flexbox;
#             display: flex;
#             -ms-flex-negative: 0;
#             flex-shrink: 0;
#             -webkit-box-pack: center;
#             -ms-flex-pack: center;
#             justify-content: center;
#             -ms-flex-item-align: start;
#             align-self: flex-start;
#             -webkit-box-align: center;
#             -ms-flex-align: center;
#             align-items: center;
#             color: #ff7955;
#             font-size: 13px;
#             height: 17px;
#             line-height: 17px;
#             font-weight: 600;
#             font-synthesis: style;" role="button">去购买
#                                 <span style="display: inline-flex; align-items: center;">&#8203;</span></div>
#                         </div>
#                     </div>
#                 </div>
#             </div>
#         </a>
#     </div>
# '''
#             for index, item in enumerate(self.words, start=1):
#                 for imgRealLink in item[1]:
#                     self.content = self.content + f'''<img style="height: 100%;
#                                   width: 100%;" src="{imgRealLink}" alt="" />'''
#                 self.content = self.content + f'''<p>{item[0]}</p>'''
#
#         return self.content
#
#     def templateFactory_forWeb(self,jdid=None,shopid=None,shopname=None,skuName=None,item_MainImg=None,item_price=None,shotUrl=None, longUrl=None,kword1=None,kword2=None):
#         return ''

class Tools_Template_New(object):
    """百家专用 """
    def templateFactory_forJDWeb(self,COOKIE,html_TEMPLATE,JDID=100016086218,pages=10):
        # 问答模板处理  非关键模块
        try:
            (askList) = JDSpider().spider_itemQueston(JDID)  # 爬取问答：
            askTemp,answersTmp = "",''
            for index, item in enumerate(askList):
                answersTmp=''
                if max(item['KEYS'], key=len, default='') == "":
                    continue
                # for answer in item['KEYS']:
                answersTmp = answersTmp+f"<p>♥{max(item['KEYS'], key=len, default='')}</p>"
                askTemp = askTemp+f"<li>问题：{item['QUESTION']}{answersTmp}</li>"
            askTemp = '''<div><ol>''' + askTemp + '''</ol></div>'''

            html_TEMPLATE = html_TEMPLATE.replace('【商品问答】', askTemp)  #替换模板 【问答模块】
        except:
            html_TEMPLATE = html_TEMPLATE.replace('【商品问答】', '')  # 替换模板 【问答模块】
            wadePrint('问答模块处理异常')

        # 爬取 商品详细参数 非关键模块
        goodName = ''
        try:
            (itemDataList) = JDSpider().spider_itemData(JDID)
            itemList = []

            for items in itemDataList:
                itemName = items[1]
                itemContent = items[2]
                if "href" in itemContent:
                    continue
                if "商品名称" in itemName:
                    goodName = items[2]
                itemList.append({"itemName": itemName, "itemContent": itemContent})
            detailTemp = ''
            for index, item in enumerate(itemList):
                detailTemp = detailTemp + f"<li>{item['itemName']}:{item['itemContent']}</li>"
            detailTemp = '''<div><ul>''' + detailTemp + '''</ul></div>'''

            html_TEMPLATE = html_TEMPLATE.replace('【商品详情】', detailTemp).replace('【商品名称】', goodName)  # 替换模板 【商品详情】
        except:
            wadePrint('商品详情参数失败')
            html_TEMPLATE = html_TEMPLATE.replace('【商品详情】', '')  # 替换模板 【商品详情】

        # 爬虫类初始化，获取图片和评论列表   获取图文列表 commentList imgList

        commentList, imgList, comments_p, imglists_p = [], [], [], []

        for i in range(0, pages):  # 爬0到PAGE要求页，超过10条就结束
            comments_p, imglists_p, results = JDSpider().spider_Newcomment(JDID, i)
            commentList.extend(comments_p)
            imgList.extend(imglists_p)
            if len(commentList) >= 10 and len(imgList) >= 10:
                random.shuffle(commentList)  # 打乱
                random.shuffle(imgList)  # 打乱
                commentList = commentList[0:7]
                imgList = imgList[0:7]
                break


        """图片转百家链接："""
        newIMGlist =[]
        for img in imgList[::-1]:  # 转换图片为Baidu链接,转换失败就去掉这个链接
            responseImgUrl = wadeTools_baiduPost_API.baiduImageUrl(imageURL='http:' + img,COOKIE=COOKIE)
            newIMGlist.append(responseImgUrl)
            # if responseImgUrl=='':  #转换失败
            #     imgList.remove(img)
        imgList = newIMGlist

        if len(imgList)==0:
            imgList.append('https://pic.rmb.bdstatic.com/bjh/down/17cdd4a0e921b469b7cf724472888c3c.jpeg') # 加个假封面

        commentList = commentList.__iter__()
        iterimgList = imgList.__iter__()
        html_TEMPLATE = html_TEMPLATE.replace('?', '')
        html_TEMPLATE = html_TEMPLATE.replace('【评论一】', next(commentList,"")).replace('【图片一】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论二】', next(commentList,"")).replace('【图片二】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论三】', next(commentList,"")).replace('【图片三】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论四】', next(commentList,"")).replace('【图片四】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论五】', next(commentList,"")).replace('【图片五】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论六】', next(commentList,"")).replace('【图片六】',next(iterimgList,""))
        wadePrint(html_TEMPLATE)
        wadePrint("文章组合成功")

        return html_TEMPLATE,imgList[0],goodName

    def templateFactory_forJDWeb_Simple(self,html_TEMPLATE,JDID=100016086218,pages=10,waitTime=0.05):
        """纯京东发帖专用 """
        try:
            (askList) = JDSpider().spider_itemQueston(JDID)  # 爬取问答：
            time.sleep(waitTime)
            askTemp,answersTmp = "",''
            for index, item in enumerate(askList):
                answersTmp=''
                if max(item['KEYS'], key=len, default='') == "":
                    continue
                # for answer in item['KEYS']:
                answersTmp = answersTmp+f"<p>♥{max(item['KEYS'], key=len, default='')}</p>"
                askTemp = askTemp+f"<li>问题：{item['QUESTION']}{answersTmp}</li>"
            askTemp = '''<div><ol>''' + askTemp + '''</ol></div>'''

            html_TEMPLATE = html_TEMPLATE.replace('【商品问答】', askTemp)  #替换模板 【问答模块】
        except:
            html_TEMPLATE = html_TEMPLATE.replace('【商品问答】', '')  # 替换模板 【问答模块】
            wadePrint('问答模块处理异常')

        # 爬取 商品详细参数 非关键模块
        goodName = ''
        try:
            itemDataList = JDSpider().spider_itemData(JDID)
            time.sleep(waitTime)
            itemList = []

            for items in itemDataList:
                itemName = items[1]
                itemContent = items[2]
                if "href" in itemContent:
                    continue
                if "商品名称" in itemName:
                    goodName = items[2]
                itemList.append({"itemName": itemName, "itemContent": itemContent})
            detailTemp = f'''<table border="1"> 
                    {''.join([f"<tr><td>{item['itemName']}</td> <td>{item['itemContent']}</td></tr>" for item in itemList])}
                </table>'''

            html_TEMPLATE = html_TEMPLATE.replace('【商品详情】', detailTemp).replace('【商品名称】', goodName)  # 替换模板 【商品详情】
        except:
            wadePrint('商品详情参数失败')
            html_TEMPLATE = html_TEMPLATE.replace('【商品详情】', '')  # 替换模板 【商品详情】

        # 爬虫类初始化，获取图片和评论列表   获取图文列表 commentList imgList
        commentList, imgList, comments_p, imglists_p = [], [], [], []

        for i in range(0, pages):  # 爬0到PAGE要求页，超过10条就结束
            time.sleep(waitTime)
            comments_p, imglists_p, results = JDSpider().spider_Newcomment(JDID, i)
            commentList.extend(comments_p)
            imgList.extend(imglists_p)
            if len(commentList) >= 8 and len(imgList) >= 8:
                random.shuffle(commentList)  # 打乱
                random.shuffle(imgList)  # 打乱
                commentList = commentList[0:7]
                imgList = imgList[0:7]
                break
        imgList = [f"http:{img}" for img in imgList]



        commentList = commentList.__iter__()
        iterimgList = imgList.__iter__()
        html_TEMPLATE = html_TEMPLATE.replace('?', '')
        html_TEMPLATE = html_TEMPLATE.replace('【评论一】', next(commentList,"")).replace('【图片一】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论二】', next(commentList,"")).replace('【图片二】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论三】', next(commentList,"")).replace('【图片三】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论四】', next(commentList,"")).replace('【图片四】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论五】', next(commentList,"")).replace('【图片五】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论六】', next(commentList,"")).replace('【图片六】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论七】', next(commentList,"")).replace('【图片七】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论八】', next(commentList,"")).replace('【图片八】',next(iterimgList,""))
        html_TEMPLATE = html_TEMPLATE.replace('【商品ID】', str(JDID))
        wadePrint(html_TEMPLATE)
        wadePrint("文章组合成功")
        if len(imgList)==0:
            # 说明没有任何图片
            raise wadeTools_error.Error_break(f"{JDID}商品无封面图，价格返回的是空值，无推广价值")
        return html_TEMPLATE,imgList[0],goodName,imgList

    def templateFactory_forJDWeb_AI(self,html_TEMPLATE, JDID=100016086218, pages=10):
        from wadeTools import wadeTools_dataoke_API, wadeTools_readConfig_ini,wadeTools_ReadAndWrite
        """OPEN ai"""
        # 通过ID获取大淘客推广链接：

        # 绝对路径
        Ini_Data = wadeTools_readConfig_ini.ReadConfig('大淘客配置.ini')
        # runNumNow = Ini_Data.get_param('USER', "runNumNow")
        '''大淘客配置文件初始化和读取'''
        materialId = f'https://item.jd.com/{JDID}.html'
        appKey = Ini_Data.get_param('USER', "appKey")
        appSecret = Ini_Data.get_param('USER', "appSecret")
        version = Ini_Data.get_param('USER', "version")
        unionId = Ini_Data.get_param('USER', "unionId")
        aiopen1close0 = Ini_Data.get_param('USER', "aiopen1close0")
        # gptWord = Ini_Data.get_param('USER', "aiopen1close0")

        # if appKey == "" or appSecret == "" or version == "" or unionId == "" or aiopen1close0=='':
        #     Ini_Data.setItem('USER', "appKey", "jd的appk")  # 修改
        #     Ini_Data.setItem('USER', "appSecret", "jd的appSecret")  # 修改
        #     Ini_Data.setItem('USER', "version", "v1.0.1")  # 修改
        #     Ini_Data.setItem('USER', "unionId", "推广者id")  # 修改
        #     Ini_Data.setItem('USER', "aiopen1close0", "1")  # 修改
        # Ini_Data.saveIni('大淘客配置.ini')  # 保存


        try:
            # 获取价格和商品图第一张
            item_detailJson = wadeTools_dataoke_API.get_dtk_detail(skuIds=JDID, appKey=appKey, appSecret=appSecret,
                                                                   version=version).json()
            # wadePrint(item_detailJson)  # 打印商品详情
            if "网络请求失败" in str(item_detailJson):
                wadePrint("网络请求失败")

        except Exception as e:
            wadePrint("请求出错，检查本段代码",e)
            raise wadeTools_error.Error_break(f"{JDID}请求出错")
        try:
            from wadeTools import wadeTools_UserJSON
            actualPrice = wadeTools_UserJSON.get_dict_by_key(will_find_dist=item_detailJson, find_keys='actualPrice')
            detailImages = wadeTools_UserJSON.get_dict_by_key(will_find_dist=item_detailJson, find_keys='detailImages')[0]
            dataokegoodName = wadeTools_UserJSON.get_dict_by_key(will_find_dist=item_detailJson, find_keys='skuName')
            # wadePrint(actualPrice, detailImages)
            int(actualPrice)  # 测试商品是否有效
        except Exception as e:
            wadePrint("商品失效，无法获取详细信息",e)
            raise wadeTools_error.Error_break(f"{JDID}商品失效，价格返回的是空值，无推广价值")

        try:
            askList = JDSpider().spider_itemQueston(JDID)  # 爬取问答：
            askTemp, answersTmp = "", ''
            for index, item in enumerate(askList):
                answersTmp = ''
                if max(item['KEYS'], key=len, default='') == "":
                    continue
                # for answer in item['KEYS']:
                answersTmp = answersTmp + f"<p>♥{max(item['KEYS'], key=len, default='')}</p>"
                askTemp = askTemp + f"<li>问题：{item['QUESTION']}{answersTmp}</li>"
            askTemp = '''<div><ol>''' + askTemp + '''</ol></div>'''

            html_TEMPLATE = html_TEMPLATE.replace('【商品问答】', askTemp)  # 替换模板 【问答模块】
        except:
            html_TEMPLATE = html_TEMPLATE.replace('【商品问答】', '')  # 替换模板 【问答模块】
            wadePrint('问答模块处理异常')


        # wadePrint(Ini_Data.getFilepath())

        # myShopLink = wadeTools_dataoke_API.getMyLink(materialId=materialId,appKey=appKey,appSecret=appSecret,version=version,unionId=unionId)
        # wadePrint(myShopLink)
        try:
            myShopLink = wadeTools_dataoke_API.getMyLink(materialId=materialId, appKey=appKey, appSecret=appSecret, version=version,unionId=unionId,limitLength=200)
            wadePrint(myShopLink)
        except:
            abc=input("请配置大淘客参数后继续运行，参数不用加引号")
            myShopLink = \
            wadeTools_dataoke_API.getMyLink(materialId=materialId, appKey=appKey, appSecret=appSecret, version=version,
                                            unionId=unionId,limitLength=200)
            wadePrint(myShopLink)

        # 爬取 商品详细参数 非关键模块
        goodName = dataokegoodName
        try:
            itemDataList = JDSpider().spider_itemData(JDID)
            itemList = []

            for items in itemDataList:
                itemName = items[1]
                itemContent = items[2]
                if "href" in itemContent:
                    continue
                # if "商品名称" in itemName:
                #     goodName = items[2]
                itemList.append({"itemName": itemName, "itemContent": itemContent[0:20]})
            detailTemp = f'''<p>{''.join([f"<li>{item['itemName']}:{item['itemContent']}</li>" for item in itemList])}</p>'''   # li模式
            # detailTemp = f'''<table>{''.join([f"<tr><td>{item['itemName']}</td>:<td>{item['itemContent']}</td></tr>" for item in itemList])}</table>'''  # 表格模式

        except:
            wadePrint('商品详情参数失败')
            detailTemp=''
            html_TEMPLATE = html_TEMPLATE.replace('【商品详情】', '')  # 替换模板 【商品详情】
        html_TEMPLATE = html_TEMPLATE.replace('【商品详情】', detailTemp).replace('【商品名称】', goodName)  # 替换模板 【商品详情】

        # 爬虫类初始化，获取图片和评论列表   获取图文列表 commentList imgList
        commentList, imgList, comments_p, imglists_p = [], [], [], []

        for i in range(0, pages):  # 爬0到PAGE要求页，超过10条就结束
            comments_p, imglists_p, results = JDSpider().spider_Newcomment(JDID, i)
            commentList.extend(comments_p)
            imgList.extend(imglists_p)
            if len(comments_p)==0 and len(imglists_p)==0:  #最热评论都是0的话就结束
                break
            if len(commentList) >= 4 and len(imgList) >= 4:
                random.shuffle(commentList)  # 打乱
                random.shuffle(imgList)  # 打乱
                break
        imgList = [f"http:{img}" for img in imgList]
        wadePrint(f"共获取图片{len(imgList)}张，评论{len(commentList)}条")
        commentList = commentList.__iter__()
        iterimgList = imgList.__iter__()




        # 多进程

        # AI 模板图片3张，评论4个
        str1 = next(commentList, "")
        str2 = next(commentList, "")
        # str3 = next(commentList, "")
        # wadePrint(str1, '\n', str2)
        try:
            if aiopen1close0 == '0':
                raise Exception
            else:
                AI_1 = str1
                AI_2 = str2
        except:
            AI_1 =str1
            AI_2 =str2
            # AI_3 =str3
        if "作为一个人工智能语言模型，我无法提供此类信息" in AI_1:
            AI_1 = str1
        if "作为一个人工智能语言模型，我无法提供此类信息" in AI_2:
            AI_2 =str2
        # if "作为一个人工智能语言模型，我无法提供此类信息" in AI_3:
            # AI_3 =str3
        # if "作为一个人工智能语言模型，我无法提供此类信息" in AI_1 or "ip一小时内连续请求了300次以上已" in AI_2 or "ip一小时内连续请求了300次以上已" in AI_2:
        #     wadePrint("次数用完")
        #     AI_1 = str1
        #     AI_2 = str2
        #     AI_3 = str3
        #     wadePrint("AI次数不够了，请更换IP继续，否则请直接退出，按回车继续。。不换账号继续会影响文章质量")
        #
        #     raise wadeTools_error.Error_break("AI次数不够了，请更换IP继续，否则请直接退出，按回车继续。。不换账号继续会影响文章质量")
            # time.sleep(999999)
        # 百度长尾词

        baiduLongWords = wadeTools_dataoke_API.baiduXiaLaWords(goodName).__iter__()
        wadePrint("百度下拉词")
        wadePrint(baiduLongWords)

        html_TEMPLATE = html_TEMPLATE.replace('?', '')
        html_TEMPLATE = html_TEMPLATE.replace('【AI语句评测1】', AI_1).replace('【图片一】', next(iterimgList, ""))
        html_TEMPLATE = html_TEMPLATE.replace('【AI语句评测2】', AI_2).replace('【图片二】', next(iterimgList, ""))
        html_TEMPLATE = html_TEMPLATE.replace('【图片三】', next(iterimgList, ""))
        html_TEMPLATE = html_TEMPLATE.replace('【评论四】', next(commentList, "")).replace('【图片四】', next(iterimgList, ""))
        html_TEMPLATE = html_TEMPLATE.replace('【商品ID】', str(JDID))
        html_TEMPLATE = html_TEMPLATE.replace('【商品推广链接】',myShopLink)
        wadePrint("百度下拉词sing1")
        if int(actualPrice)>=150:
            actualPrice = int(actualPrice)
        else:
            actualPrice=int(actualPrice)


        html_TEMPLATE = html_TEMPLATE.replace('【商品价格】',str(actualPrice))
        html_TEMPLATE = html_TEMPLATE.replace('【商品封面】',detailImages)
        html_TEMPLATE = html_TEMPLATE.replace('【文章标题】',f'{goodName[0:24]}{wadeTools_ReadAndWrite.lunxunTxt("标题后缀.txt")}')
        html_TEMPLATE = html_TEMPLATE.replace('【商品名称】',f'{goodName[0:24]}')
        html_TEMPLATE = html_TEMPLATE.replace('【商品卡片名称】',f'{goodName[0:24]}')
        wadePrint("百度下拉词sing2")
        html_TEMPLATE = html_TEMPLATE.replace('【轮链1】',f'{wadeTools_ReadAndWrite.lunxunTxt("./发帖结果/发布成功文章记录.txt")}')
        html_TEMPLATE = html_TEMPLATE.replace('【轮链2】',f'{wadeTools_ReadAndWrite.lunxunTxt("./发帖结果/发布成功文章记录.txt")}')
        wadePrint("百度下拉词sing3")
        html_TEMPLATE = html_TEMPLATE.replace('【轮链3】',f'{wadeTools_ReadAndWrite.lunxunTxt("./发帖结果/发布成功文章记录.txt")}')
        html_TEMPLATE = html_TEMPLATE.replace('【百度长尾词】',f'{next(baiduLongWords,"")}')
        # wadePrint(html_TEMPLATE)
        wadePrint("文章组合成功")
        if len(imgList)==0:
            imgList.append(detailImages)
        wadePrint(imgList)
        wadePrint(imgList[0], goodName,JDID)
        return html_TEMPLATE, imgList[0], goodName


if __name__ == '__main__':
    # #百家发帖流程
    html_TEMPLATE ='''<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
    <span>
        <strong style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
        前言
        </strong>
    </span>
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;所有具备超赞的旗舰产品，自然是将用户体验全部拉满，精美工艺、质量口碑上上选、回血迅速…这些属性可一样也不能少，【商品名称】可以说是我们生活中“超亲密”的产品了。现在的产品细分市场太激烈了,很多人在选择上还是选择“感性”，性急的稀里糊涂的被动入手了。那刚好最近正在研究这款【商品名称】，今天就让笔者带大家尽情领悟它的不凡实力吧。
      </span>
</p>
<p>
	<img src="【图片一】" alt="" />
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
    <span>
        <strong style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
        设计：匠心独具
        </strong>
    </span>
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;本次到手的【商品名称】，【评论一】
      </span>
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;觉得不错的话可以到官网看看商品参数，我已经给大家找到了官方的详情，不想浪费时间的可以入手啦
      </span>
</p>
<div id="商品卡" ></div>
<div id="商品问答" ></div>
热度评分：【热度评分】分


印象评分：【印象评分】分


综合评分：【综合评分】分
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
    <span>
        <strong style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
        产品参数指标
        </strong>
    </span>
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;【评论二】
      </span>
</p>
<p>
	<img src="【图片二】" alt="" />
</p>
【商品参数】
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
    <span>
        <strong style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
        网友关注的【商品名称】问题
        </strong>
    </span>
</p>
【商品问答】
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
    <span>
        <strong style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
        网友贴心反馈
        </strong>
    </span>
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;【评论三】
      </span>
</p>
<p>
	<img src="【图片三】" alt="" />
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;【评论四】
      </span>
</p>
<p>
	<img src="【图片四】" alt="" />
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;【评论五】
      </span>
</p>


<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
    <span>
        <strong style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box">
        结语
        </strong>
    </span>
</p>
<p style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      <span style="margin: 0px;padding: 0px;border: 0px;outline: 0px;vertical-align: initial;background: 0px 0px;-webkit-tap-highlight-color: transparent;max-width: 100%;overflow-wrap: break-word;box-sizing: border-box" >
      &nbsp;&nbsp;&nbsp;&nbsp;&#8203;经过笔者全方位的体验，【商品名称】表现真的赞啊。这么好的产品无论是在家用还是送亲朋好友，都能很好的，笔者决定自己留着用了嘎嘎。以上是【商品名称】使用过程中的体会，如果这次的分享文章对你有的选择有所帮助，记得点个赞支持哦~。
      </span>
</p>
'''
    wadePrint(Tools_Template_New().templateFactory_forJDWeb_AI(html_TEMPLATE=html_TEMPLATE,JDID=100016086218,pages=20)[0])





import json
import time
'''
这里是关于json内容的工具库
#再也不用一个一个找JSON的位置了，直接查找，返回第一项匹配的字符串，如果找不到反馈"空值"
get_dict_by_key(will_find_dist, find_keys):  # will_find_dist要查找的字典，find_keys要查找的keys，found找到值存放处

get_dict_by_key_method(will_find_dist, find_keys)  #返回的类型是列表，空的返回[]


'''
def getValueList_From_Dict_By_Key_ExceptSbKey(will_find_dist, find_keys,notWantKeyList):  # will_find_dist要查找的字典，find_keys要查找的keys，found找到值存放处,notWantKeyList 把不需要遍历的列表放进去 ["不想要的key1","不想要的Key2"]
    value_found = []
    if (isinstance(will_find_dist, (list))):  # 含有列表的值处理
        if (len(will_find_dist) > 0):
            for now_dist in will_find_dist:
                found = get_dict_by_key_method(now_dist, find_keys)
                if (found):
                    value_found.extend(found)
            return value_found

    if (not isinstance(will_find_dist, (dict))):  # 没有字典类型的了
        return 0

    else:  # 查找下一层
        dict_key = will_find_dist.keys()
        # print (dict_key)
        for i in dict_key:
            if i in notWantKeyList:
                continue
            if (i == find_keys):
                value_found.append(will_find_dist[i])
            found = get_dict_by_key_method(will_find_dist[i], find_keys)
            if (found):
                value_found.extend(found)
        return value_found

def get_dict_by_key_method(will_find_dist, find_keys):  # will_find_dist要查找的字典，find_keys要查找的keys，found找到值存放处
    value_found = []
    if (isinstance(will_find_dist, (list))):  # 含有列表的值处理
        if (len(will_find_dist) > 0):
            for now_dist in will_find_dist:
                found = get_dict_by_key_method(now_dist, find_keys)
                if (found):
                    value_found.extend(found)
            return value_found

    if (not isinstance(will_find_dist, (dict))):  # 没有字典类型的了
        return 0

    else:  # 查找下一层
        dict_key = will_find_dist.keys()
        # print (dict_key)
        for i in dict_key:
            if (i == find_keys):
                value_found.append(will_find_dist[i])
            found = get_dict_by_key_method(will_find_dist[i], find_keys)
            if (found):
                value_found.extend(found)
        return value_found
def get_dict_by_key(will_find_dist, find_keys):  # will_find_dist要查找的字典，find_keys要查找的keys，found找到值存放处
    result = get_dict_by_key_method(will_find_dist, find_keys)
    if len(result) ==0:
        return '空值'
    else:
        return result[0]

def readjson(jsonname):
    with open(jsonname, 'r',encoding='utf-8') as f:
        data = json.load(f)

    return data

def savejson(data,jsonname):
    # Writing JSON data
    with open(jsonname, 'w',encoding='utf-8') as f:
        json.dump(data, f,ensure_ascii=False, indent=4)


def createJsonFile(jsonname):
    initJson = {}
    savejson(initJson, jsonname)

def jsonDataAdd(jsonname,userName,num):
    userjson = readjson(jsonname)
    DataTime = time.strftime('%Y%m%d', time.localtime(time.time()))
    name = userName
    numm = num
    userjson[name] = [numm, DataTime]
    savejson(userjson, jsonname)

# json清空记录初始化
def jsonDateInit(jsonname):
    userjson = readjson(jsonname)
    DataTime = time.strftime('%Y%m%d', time.localtime(time.time()))
    for user in userjson:
        userjson[user][0] = 0
        userjson[user][1] = DataTime
    savejson(userjson,jsonname)
    print('json初始化成功')

def jsonClearAllUsers(jsonname):
    userjson = readjson(jsonname)
    userjson.clear()
    savejson(userjson,jsonname)

def deletUser(username,jsonname):
    userjson = readjson(jsonname)
    if username in userjson:
        userjson.pop(username)
        savejson(userjson,jsonname)
        print(f"成功删除用户:{username}")
    else:
        print("不存在该用户")

def getUserPOSTNum(username,jsonname):
    userjson = readjson(jsonname)
    if username in userjson:
        return userjson[username][0]
    else:
        print("不存在该用户")


if __name__ == '__main__':
    jsonname ='user.json'
    deletUser('用户名',jsonname)   #删除用户
    #
    # jsonDataAdd(jsonname,'xiaohong',3) #增加用户
    #
    # jsonDateInit(jsonname)  #初始化用户次数
    # jsonClearAllUsers(jsonname)

    # getUserPOSTNum('xiaohu', jsonname)  #

    # createJsonFile(jsonname)  #初始化



import ollama


# 初始化带历史记忆的对话
def continuous_chat():
    history = [
        {"role": "system", "content": "对话需保持连贯，参考历史记录回答"}
    ]
    while True:
        user_input = input("User: ")
        if user_input.lower() == "exit":
            break
        history.append({"role": "user", "content": user_input})

        response = ollama.chat(
            model='gemma3:4b',
            messages=history,
            options={'temperature': 0.5}
        )
        print(f"AI: {response['message']['content']}")
        history.append({"role": "assistant", "content": response['message']['content']})
        print(history)


if __name__ == '__main__':
    continuous_chat()


# encoding=utf-8
'''关于文字/文本处理的专用库'''
# 取出两个字符串中间的部分,用在查找匹配上贼好用

import re
import re
# 替换非法字符
def sanitize_folder_name(title):
    # 替换非法字符为下划线
    sanitized = re.sub(r'[\\/?:*"<>|]', '_', title)
    # 可选：去除首尾空格
    sanitized = sanitized.strip()
    return sanitized


def getDefaultBadWords():  #垃圾词，返回列表
    badWordList = ["此用户未填写评",
                   "此用户未及时填写评价",
                   "差",
                   "坏",
                   "黑心",
                   "不好",
                   "此用户没有填写评价",
                   "太垃圾",
                   "辣鸡",
                   "太差",
                   "恶心",
                   "骂",
                   "太慢",
                   "差评",
                   "破了",
                   "烂",
                   "垃圾",
                   "质量差",
                   "不要买",
                   "差评",
                   "坏了",
                   "刷",
                   "评论",
                   "别买",
                   "后悔",
                   "真烂",
                   "寒心",
                   "辣鸡",
                   "不推荐",
                   "太差",
                   "慎重买",
                   "投诉",
                   "退货",
                   "不负责任",
                   "有缺陷",
                   "傻逼",
                   "fuck",
                   "滚你",
                   "坑爹",
                   "**",
                   ]
    return badWordList


def wade_match_MiddleText(A, B, content):
    regex1 = re.compile(rf'{A}(.*?){B}')
    print(regex1)
    reResult = regex1.findall(content)
    print(reResult)
    return reResult


def delBadItemFromList(dataList: list, badWordList: list):  # 把字符串列表中，不想要的条目删去
    for badWord in badWordList:
        for item in dataList[::-1]:
            if badWord in item:
                dataList.remove(item)


    return [filter_str(i) for i in dataList]  # 在filter_str过滤下非法字符

# 过滤任何垃圾字符
def filter_str(desstr, restr=''):
    # 过滤除中英文及数字以外的其他字符
    res = re.compile("[^\\u4e00-\\u9fa5^a-z^A-Z^0-9^:^：^！^@^#^￥^%^&^（^）^(^)^$^!^@^^_^+]")
    return res.sub(restr, desstr)

if __name__ == '__main__':
    datalist = ["我爱你", "我杀了你"]
    badWordList = ['了']
    print(delBadItemFromList(datalist, badWordList))
    print(filter_str("我爱你:!@"))



import yagmail
import wadeTools.wadeTools_log
my_logger = wadeTools.wadeTools_log.MyLogger.create_logger()
def sendEmail(email,title,content):
    """
    发送邮件的函数，使用jiuyinwadevip@163.com来进行操作.
    :param email:邮件地址
    :param title:标题
    :param content:内容
    :return: 无返回
    """
    try:
        # 链接邮箱服务器
        yag = yagmail.SMTP(user="jiuyinwadevip@163.com", password="test123456789", host='smtp.163.com')
        # 邮箱正文
        contents = [f'{content}']
        # 发送邮件
        yag.send(f'{email}', f'{title}', contents)

    except Exception as e:
        my_logger.debug(e)
        pass

if __name__ == '__main__':
    # sendEmail('317909531@qq.com','这是来自我的一封信','我很好，我是内容')
    my_logger.setLevel('DEBUG')
    my_logger.debug("nif12adf")


import re


def extract_jd_product_id(url):
    # 正则匹配，支持item.jd.com和mitem.jd.hk等域名
    # 匹配规则：
    # - 支持item.jd.com或mitem.jd.hk等域名
    # - 支持/product/路径或直接跟商品ID的情况
    pattern = r'(?:item(?:\.m)?\.jd\.com|mitem\.jd\.hk)/(?:product/)?(\d+)\.html'
    match = re.search(pattern, url)

    if match:
        product_id = match.group(1)  # 提取第一个捕获组的内容
        print(f"提取的商品ID：{product_id}")
        return product_id
    else:
        print("未找到匹配的商品ID")
        return None


# 测试
url1 = "https://mitem.jd.hk/product/100017184844.html?cu=true&utm_source=lianmeng__9__kong&utm_medium=jingfen&utm_campaign=t_1001706833_&utm_term=e6cabdf3c43d4420a21225b54e5b9730&scid=3bc8b325-42a3-437f-ae70-def46708cabc"
url2 = "https://item.jd.com/product/100015760597.html"
url3 = "https://item.m.jd.com/100015760598.html"

extract_jd_product_id(url1)  # 应输出：100017184844
extract_jd_product_id(url2)  # 应输出：100015760597
extract_jd_product_id(url3)  # 应输出：100015760598



#!/usr/bin/env python
# coding=utf-8
# author:wade
# contact: 317909531@qq.com
# datetime:2021/12/5 22:14
#requests.head(url).headers 可以在请求之前获取服务器需要的提交类型

"""
文件说明：
geiUrl函数，传入链接，获取内容

wade_Request_get  和geturl一个意思，加入了新的功能

def wade_Request_get(url,cookie,addHeader=dict):
    url：传入链接
    addHeader：是需要的内容更新进请求header中，默认的host自动化解析


def retryRequest(func)
    重连问题解决

def get_Request_JsFiles(htmlText)
    传入html.text，匹配到js列表返回


# requests库中的params参数用于向URL添加查询字符串，data参数用于向请求体添加表单数据（如POST请求），而json参数用于向请求体添加JSON数据。具体来说:
# params：将参数以键值对形式附加到URL的查询字符串中，常用于GET请求。
# data：以字典或元组列表的形式提供表单数据，发送POST请求时使用，Content-Type为application/x-www-form-urlencoded。
# json：以字典或任何可序列化的对象提供JSON数据，发送POST请求时使用，Content-Type为application/json。
# 总的来说，params和data都是向请求添加参数的方式，但data主要用于传递表单数据，而json则用于传递结构化的数据。
#   :param url: 请求地址
#   :param method: 请求方法，默认为 GET
#   :param headers: 请求头信息，默认为 None  headers = {'User-Agent': 'Mozilla/5.0'}  r = requests.get('https://httpbin.org/get', headers=headers)
#   :param params: URL 参数，默认为 None     payload = {'key1': 'value1', 'key2': 'value2'}   r = requests.get('https://httpbin.org/get', params=payload)
#   :param data: 发送的数据。通常用于POST请求,默认为 None payload = {'key1': 'value1', 'key2': 'value2'} response = requests.post(url, data=payload)
#   :param json: JSON 数据，默认为 None payload = {'key1': 'value1', 'key2': 'value2'} response = requests.post(url, json=payload)
#   :param cookies: Cookie 信息，默认为 None  cookies = {'name': 'value'}  response = requests.get(url, cookies=cookies)
#   :param files: 上传的文件，默认为 None files = {'file': open('test.txt', 'rb')} response = requests.post(url, files=files)
#   :param proxies: 代理信息，默认为 None  proxies = {'http': 'http://127.0.0.1:8888', 'https': 'http://127.0.0.1:8888'}  response = requests.get(url, proxies=proxies)
#   :param verify: SSL证书验证，默认为 None  response = requests.get(url, verify=False)
# 禁用证书验证
r = requests.get('https://httpbin.org/get', verify=False)

# 使用证书验证
r = requests.get('https://httpbin.org/get', cert=('path/to/cert.pem', 'path/to/key.pem'))
#   :return: 响应对象
"""
import random
import re
import time

import pandas as pd
import requests
from bs4 import BeautifulSoup
from requests import Timeout, ConnectTimeout
from requests.exceptions import InvalidProxyURL, ProxyError, MissingSchema, ReadTimeout, SSLError
from wadeTools import wadeTools_error
#这个可以解决重连的问题，用他做装饰器就可以了（装饰器）

HEADERS = ["Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36 QuarkPC/4.2.5.446"]

def retryRequest(func):
    RETRIES = 1# 重试的次数
    count = {"num": RETRIES}

    def wrapped(*args, **kwargs):
        try:
            # print(count['num'])
            return func(*args, **kwargs)
        except (SSLError,ProxyError,ReadTimeout,Timeout,ConnectionError,ConnectTimeout):  # (SSL链接错误，被拉黑/请求格式错/代理超时)代理成功,代理连接不上URL，1、url错误  2 url没反应 ，但通过代理访问的URL出问题,可能是url错误，可能是被服务器拉黑无任何反应
            if count['num'] == 1:
                 print('本地ip请求不成功，再试一次',count['num'])
                 count['num'] += 1
            elif count['num'] <= 10:
                 print('代理请求不成功，切换新的代理',count['num'])
                 # kwargs['proxies'] = wadeTools_Agent.getAGENT()
                 count['num'] += 1
            else:
                raise wadeTools_error.Error_break("使用代理10次访问仍然出现问题，请检查url后再运行")

            return wrapped(*args, **kwargs)
    return wrapped
#这个可以解决重连的问题，用他做装饰器就可以了（范例函数）

def myRequest():
    print("haha")
    url= 'http://www.tbzhu1.com'
    session = requests.session()
    html = session.get(url)
    print(html.url)
    # if html.url == 'http://www.tbzhu.com/':  #可以根据判断来辨别是否是自己想要得结果，不是的话也可以重连
    #     raise Exception


def wade_Request_get(url,addHeader=dict,proxies=None,timeout=10):   #proxies 默认是不用写得
    from urllib.parse import urlparse  # 正则url标准库

    headers = {
        'Accept': '*/*',
        # 'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'User-Agent': random.choice(HEADERS),
        'Connection': 'keep-alive',
        'Host': f"{urlparse(url).netloc}",
        'Content-Type': 'application/json',
        # 'Cookie': cookie
    }
    if addHeader:
        headers.update(addHeader)
    # print(headers)
    if proxies:
        html = requests.get(url, headers=headers,proxies=proxies,timeout= timeout)
    else:
        html = requests.get(url, headers=headers,timeout= timeout)
    return html

def wade_Request_get_byParams(url,addHeader=dict,params=None):
    from urllib.parse import urlparse  # 正则url标准库

    headers = {
        'Accept': '*/*',
        # 'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'User-Agent': random.choice(HEADERS),
        'Connection': 'keep-alive',
        'Host': f"{urlparse(url).netloc}",
        'Content-Type': 'application/json',
        # 'Cookie': cookie
    }
    if addHeader:
        headers.update(addHeader)
    # print(headers)
    html = requests.get(url, headers=headers,params=params)
    return html

@retryRequest
def wade_Request_post(url,addHeader=dict,data=dict):
    from urllib.parse import urlparse  # 正则url标准库

    headers = {
        'Accept': '*/*',
        # 'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'User-Agent': random.choice(HEADERS),
        'Connection': 'keep-alive',
        'Host': f"{urlparse(url).netloc}",
        'Content-Type': 'application/json',
        # 'Cookie': cookie
    }
    if addHeader:
        headers.update(addHeader)
    #print(headers)
    html = requests.post(url, headers=headers,data=data)
    return html
@retryRequest
def wade_Request_post_CSRF(url,addHeader=dict,data=dict):
    from urllib.parse import urlparse  # 正则url标准库
    headers = {
        'Accept': '*/*',
        # 'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'User-Agent': random.choice(HEADERS),
        'Connection': 'keep-alive',
        'Host': f"{urlparse(url).netloc}",
        'Content-Type': 'application/json',
        # 'Cookie': cookie
    }
    if addHeader:
        headers.update(addHeader)
    #print(headers)
    html = requests.post(url, headers=headers,data=data)
    return html

def get_Request_JsFiles(htmlText):
    # 获取网页中包含的所有js网址，目的是为了抓js中的内容
    patternjs1 = '<script src="(.*?)"'
    patternjs2 = '<script type="text/javascript" src="(.*?)"'
    list = re.compile(patternjs1, re.S).findall(htmlText)
    list += re.compile(patternjs2, re.S).findall(htmlText)
    # print(list)
    return list


def getheaders(s):  #格式化header,可以把复制的header直接变成格式化后的来用，从Accept: */*开始复制
    ls = s.split('\n')
    lsl = []
    ls = ls[1:-1]
    headers = {}
    for l in ls:
        l = l.split(': ')
        lsl.append(l)

    for x in lsl:
        headers[str(x[0]).strip('    ')] = x[1]
    print(headers)
    return headers
@retryRequest
def geiUrl(url):
    HEADERS = [
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.75 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.117 Safari/537.36',
        'Mozilla/5.0 (Windows;U;WindowsNT6.1;en-us)AppleWebKit/534.50(KHTML,likeGecko)Version/5.1Safari/534.50',
        'Mozilla/5.0 (Macintosh;IntelMacOSX10.6;rv:2.0.1)Gecko/20100101Firefox/4.0.1',
        'Mozilla/5.0 (Windows NT6.1;rv:2.0.1)Gecko/20100101Firefox/4.0.1',
        'Mozilla/5.0 (Macintosh;IntelMacOSX10_7_0)AppleWebKit/535.11(KHTML,likeGecko)Chrome/17.0.963.56Safari/535.11',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36',
        'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36',
        'Mozilla/5.0 (Windows NT 6.3; WOW64; rv:41.0) Gecko/20100101 Firefox/41.0',
        'Mozilla/5.0 (Windows NT 6.3; Trident/7.0; rv:11.0) like Gecko',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.102 Safari/537.36 Edge/18.18362',
        'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/69.0.3497.100 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:71.0) Gecko/20100101 Firefox/71.0',
        'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 UBrowser/6.2.4098.3 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36',
        'Mozilla/5.0 (Macintosh;U;IntelMacOSX10_6_8;en-us)AppleWebKit/534.50(KHTML,likeGecko)Version/5.1Safari/534.50',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2486.0 Safari/537.36 Edge/13.10586',
        'Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27',
        'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11) AppleWebKit/601.1.27 (KHTML, like Gecko) Chrome/47.0.2526.106 Safari/601.1.27',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:70.0) Gecko/20100101 Firefox/70.0',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.79 Safari/537.36',
    ]

    # 采用正则，抓tbk链接
    # url = f"https://question.jd.com/question/getQuestionAnswerList.action?callback=jQuery8364807&page=2&productId"
    # 采用正则，抓tbk链接
    match = re.compile(r'''//(\S*\.["com"|"cn"|"com.cn"]+)''')
    result = match.findall(url)
    # print(abc[0])
    if not result: #如果没有找到url，报错
        print('url的格式不对，函数停止')
        return
    headers = {
        'Accept': '*/*',
        'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'User-Agent': random.choice(HEADERS),
        'Connection': 'keep-alive',
        'Host': f"{result[0]}",
        'Content-Type': 'application/json'
    }
    print(headers)
    html = requests.get(url,headers = headers)
    print(html.headers)
    return html
@retryRequest
def bookInfo(url):  #抓笔记本数据
    # 采用正则，抓tbk链接
    html = geiUrl(url)
    print('--------请求中-----------')
    # print(html.text)
    print('---------开始格式化html，加载beautifulSoup------------')
    soup = BeautifulSoup(html.text,'lxml')  # html为html源代码字符串，type(html) == str
    # print(soup.prettify())   #美化输出 格式化html
    print('---------开始清洗数据------------')

    pdData_dict={}
    pdData_dict["name"] = soup.h3.text

    for tr_s in soup.table.children:  #判断如果子节点的兄弟节点不存在的话，直接跳过
        if tr_s.next_element.next_sibling== None:
            continue
        # print(tr_s.next_element.next_element)
        if (tr_s.next_element.next_element.name == 'span' or tr_s.next_element.next_element.name == 'b') and tr_s.next_element.next_sibling.name == "td":
            pdData_dict[f'{tr_s.next_element.next_element.string}'] = [tr_s.next_element.next_sibling.string]
    print(pdData_dict)

    df_new = pd.DataFrame(pdData_dict)
    return df_new,pdData_dict["name"]
if __name__ == '__main__':
    # url = f"https://detail.zol.com.cn/param_copy_1343674_blue_2_0_560.html"
    from threading import Thread

    import requests


    proxies = {
        "http": '',
        "https": ''
    }


    def changeAgent():
        global proxies
        url = 'https://proxy.qg.net/allocate?Key=9XFOUQ5B&Num=1&AreaId=&DataFormat=txt&DataSeparator=%5Cr%5Cn&Detail=0'
        html = requests.get(url, timeout=10)
        print('切换新代理：', html.text)
        key = '9XFOUQ5B'
        passwd = '2F5079EA8A6B'
        proxy = f'http://{key}:{passwd}@{html.text}'

        proxies = {
            "http": proxy,
            "https": proxy
        }
        return proxies


    def getAgent():
        global proxies
        # if proxies["http"]=="" and proxies["https"]=="":
        #     changeAgent()
        print(proxies)
        return proxies


    def changeAgentButton():  # 默认直接显示

        sg.theme('DarkAmber')  # 设置当前主题色
        # 界面布局，将会按照列表顺序从上往下依次排列，二级列表中，从左往右依此排列
        layout = [[sg.B("切换代理", key="切换代理")]]

        def my_long_operation():
            print("点击按钮")
            changeAgent()

        # 创造窗口
        windows = sg.Window('代理窗口', layout, location=(0, 0), font=("宋体", 10))

        while True:
            event, values = windows.Read()
            if event == sg.WIN_CLOSED or event == 'Exit':
                print('代理窗口关闭')
                break
            if event == '切换代理':  # 登录按钮
                windows.perform_long_operation(my_long_operation, '-finish-')

        windows.close()


    # proxies= {'http': 'http://9XFOUQ5B:2F5079EA8A6B@117.91.61.202:26745', 'https': 'http://9XFOUQ5B:2F5079EA8A6B@117.91.61.202:26745'}
    changeAgent()
    url = f"http://www.youtube.com"

    # html = wade_Request_get(url=url,addHeader={})
    # # print(html.text)
    # print(requests.head(url).headers)
    # print(requests.head(url).headers['Content-Type'])
    # print(type(requests.head(url).headers))
    # a = requests.get("http://www.youtube.com")
    # print(a.text)
    a = requests.get(url,proxies=getAgent())
    print(a.status_code)
    print(a.text)




    # df_new,new_name = bookInfo(url)  #返回抓到的数据
    # # df_new.to_csv(path_or_buf='产品清单.csv',index=False)
    # # print("======================")
    #
    # try:
    #     df_readData = pd.read_csv("产品清单.csv", encoding="gbk")
    #     print(df_readData)
    # except:
    #     df_new.to_csv(path_or_buf='产品清单.csv',index=False,encoding="gbk")
    #     df_readData = pd.read_csv("产品清单.csv", encoding="gbk")
    #     print("======================")
    #
    # if not find_needData(df_readData,"name",new_name):
    #     # 合并DataFrame 数据
    #     resule = pd.concat([df_readData, df_new], join='outer', sort=True)
    #     resule.to_csv(path_or_buf='产品清单.csv', index=False,encoding="gbk")
    #     print(f"成功加入一条数据 {new_name}")
    # else:
    #     print("已存在")





















from wadeTools.wadeTools_Print import wadePrint, wadeRedPrint, wadeBluePrint


def wadeDeepSeek(content):
    import os
    from openai import OpenAI

    client = OpenAI(
        # 请用知识引擎原子能力API Key将下行替换为：api_key="sk-xxx",
        api_key="sk-KxoONWmmQHhiiFtJrqYb7u49qb3YCZGSrtTTo9UBQPF3rtsQ",  # 如何获取API Key：https://cloud.tencent.com/document/product/1772/115970
        base_url="https://api.lkeap.cloud.tencent.com/v1",
    )

    completion = client.chat.completions.create(
        model="deepseek-r1",  # 此处以 deepseek-r1 为例，可按需更换模型名称。
        messages=[
            {'role': 'user', 'content': f'{content}'}
        ]
    )

    # 通过reasoning_content字段打印思考过程
    wadeBluePrint("思考过程：")
    print(completion.choices[0].message.reasoning_content)
    # 通过content字段打印最终答案
    wadeBluePrint("最终答案：")
    print(completion.choices[0].message.content)
    return completion.choices[0].message.content

def wadeGetGPT(content):
    import requests
    import json

    url = "https://api.lightai.io/v1/chat/completions"

    payload = json.dumps({
        "model": "gpt-4o-mini",
        "messages": [
            {
                "role": "system",
                "content":f"{content}"
            }
        ]
    })
    headers = {
        'TE': 'trailers',
        'Authorization': 'Bearer sk-WusbK0hWlw5GVqBt195c04B674B940B2AbC84d2c4aF82c4b',
        'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
        'Content-Type': 'application/json'
    }
    response = requests.request("POST", url, headers=headers, data=payload)
    # print(response.text)
    return response.json()

def ollama(content):

if __name__ == '__main__':
    # from wadeTools.wadeTools_UserJSON import get_dict_by_key
    # wadePrint(get_dict_by_key(wadeGetGPT("美的空调 家电国家补贴 酷省电 大1.5匹 新一级能效 变频冷暖 节能 卧室壁挂式挂机 KFR-35GW/N8KS1-1   # 角色 你是一位超级擅长创作口水鸡汤风格爆款标题的知乎和小红书大师级作者。当接收到京东商品标题或者京东链接时，你要像魔法精灵一样，充分施展创意魔法，把它变成极具吸引力、完美契合口水鸡汤风格且能大幅提升点击率，字数在15到20字之间的爆款标题，且标题中尽量出现商品型号。## 技能 ### 技能1: 炮制爆款标题1. 若收到的是京东链接，调用插件京东购物 / jdshop学习该商品内容，务必精准获取商品型号；若收到的是京东商品标题，则直接开启深度剖析模式。精准抓住商品的独特卖点、能满足的情感需求以及目标受众的心理痛点。2. 调用百度插件，搜索该商品关键词，找出同类型且让消费者难以判断买哪个的对标商品。以温暖、励志、引人共鸣的口水鸡汤风格语言为基石，融入网络流行元素、情感钩子等点击率高的标题创作技巧，将对标商品与该商品对比，精心打造一个字数在15到20汉字之间且尽量包含商品型号的爆款标题。3. 确保创作的标题能瞬间抓住读者眼球，激发他们强烈的好奇与情感共鸣，促使他们迫不及待想要一探究竟。## 限制:- 创作范围严格限定在接收到的京东商品标题或京东链接相关商品，对其他无关话题一概不予理会。- 输出必须是完全原创、紧扣口水鸡汤风格且符合高点击率标题范式，字数在15到20字之间的内容，杜绝抄袭和机械应付。  每次的创作要有新意，用哪个好，怎么样，等爆款来结尾"),'content'))
    wadeDeepSeek(content='你好')



""" 需要固定数量的线程时候，用简单的方法来最直观 import time, threading
    lock = threading.Lock()  #感觉资源会冲突加个锁
    with lock:
        pass

"""
from concurrent.futures import as_completed

""" 有大量相同任务需要并行的话，采用线程池concurrent.futures模块来比较省事 from concurrent.futures import ThreadPoolExecutor"""
import time,threading
from wadeTools import wadeTools_Police
from concurrent import futures
import tkinter
def a(name):
    time.sleep(2)
    print(f"睡了{name}秒")
    return threading.current_thread().name,threading.active_count()
def b(name):
    timess =5
    time.sleep(timess)
    print(f"睡了{timess}秒")
    return 5

@wadeTools_Police.cost_time
def threadExample():
    thread_obj1 = threading.Thread(target=a,name="hellow",args=("name",))
    thread_obj2 = threading.Thread(target=b,name="nihao",args=("name",))
    thread_obj1.start()
    thread_obj2.start()
    thread_obj1.join()  # 让主进程等你呦
    thread_obj2.join()
    print(thread_obj1.name)
    print(thread_obj1.is_alive())

def ThreadPoolExample():
    # 功能同上executor.submit()遍历
    with futures.ThreadPoolExecutor(max_workers=5) as pool:
        taskList =[]
        task1 = pool.submit(a,int(time.time()*1000))
        task2 = pool.submit(a,int(time.time()*1000))
        taskList.append(task1)
        taskList.append(task2)

    for future in futures.as_completed(taskList):
        result = future.result()
        print("线程%s拿到的返回值%s" % (threading.current_thread().name, result))
    pool.shutdown()
    print(task1.running())




if __name__ == '__main__':
    threadExample()

    # # 我想 实现一个状态监控窗口，里边有控制单元
    # # 输入名字、按钮变量、功能函数、运行时候可以随时控制
    # window = tkinter.Tk()
    # def func():
    #     print('我被触发了')
    # def refresh_data():
    #     print(123)
    #     window.after(1, refresh_data)



    # window.after(100, refresh_data)  # 这里的100单位为毫秒
    # window.mainloop()